@@ -63,7 +63,7 @@
 #include"konoha/konoha_debug.h"
 #include"konoha/konoha_glue.h"
 #include"konoha/konoha_gc.h"
-//#include"konoha/konoha_vm.h"
+#include"konoha/konoha_vm.h"
 
 /* konohaapi, prototypes */
 
