@@ -477,10 +477,6 @@ typedef knh_ushort_t              knh_uri_t;
 #define knh_thread_t W
 #define knh_thread_key_t W
 #define knh_mutex_t W
-#elif defined(KONOHA_ON_WINDOWS)
-#define knh_thread_t HANDLE
-#define knh_thread_key_t DWORD
-#define knh_mutex_t CRITICAL_SECTION
 #else
 typedef knh_intptr_t knh_thread_t;
 typedef knh_intptr_t knh_thread_key_t;
@@ -500,72 +496,49 @@ typedef void *(*knh_Fthread)(void *);
 /* Stack Frame Pointer */
 /* ------------------------------------------------------------------------ */
 
-#define ASSERT_SFP(sfp)  KNH_ASSERT(((((knh_rbp_t*)sfp) - ((knh_rbp_t*)(ctx->stack))) % 2) == 0)
-
-#define K_FRAME_NCMEMBER \
-		knh_boolean_t bvalue; \
-		knh_int_t     ivalue; \
-		knh_uint_t    uvalue; \
-		knh_float_t   fvalue; \
-		knh_uint64_t  data;   \
-		knh_intptr_t  shift;  \
-		struct knh_opline_t     *pc; \
-		struct knh_Method_t     *mtdNC; \
-		struct knh_Translator_t *trlNC \
-
-#define K_FRAME_MEMBER \
-		Object *o; \
-		struct knh_Int_t    *i; \
-		struct knh_Float_t  *f; \
-		struct knh_Class_t  *c; \
-		struct knh_String_t *s; \
-		struct knh_Bytes_t  *ba; \
-		struct knh_Regex_t  *re; \
-		struct knh_Tuple_t  *tuple; \
-		struct knh_Range_t  *range; \
-		struct knh_Array_t  *a; \
-		struct knh_Iterator_t *it; \
-		struct knh_Map_t    *m;    \
-		struct knh_Func_t         *fo; \
-		struct knh_InputStream_t  *in; \
-		struct knh_OutputStream_t *w;  \
-		struct knh_Method_t *mtdOBJ;   \
-		struct knh_Translator_t *trlOBJ; \
-		struct knh_Exception_t *e;       \
-		struct knh_ExceptionHandler_t *hdr; \
-		struct knh_NameSpace_t *ns; \
-		struct knh_RawPtr_t   *p; \
-		struct knh_ObjectField_t *ox; \
-		struct knh_Converter_t *conv; \
-		knh_int_t     dummy_ivalue; \
-		knh_float_t   dummy_fvalue \
-
 typedef struct knh_sfp_t {
 	union {
-		K_FRAME_MEMBER;
+		knh_boolean_t bvalue;
+		knh_int_t     ivalue;
+		knh_uint_t    uvalue;
+		knh_float_t   fvalue;
+		knh_uint64_t  data;
+		knh_intptr_t  shift;
+		struct knh_opline_t     *pc;
+		struct knh_Method_t     *callmtd;
+		struct knh_Translator_t *casttrl;
 	};
 	union {
-		K_FRAME_NCMEMBER;
+		void   *ref;
+		Object *o;
+		struct knh_Int_t    *i;
+		struct knh_Float_t  *f;
+		struct knh_Class_t  *c;
+		struct knh_String_t *s;
+		struct knh_Bytes_t  *ba;
+		struct knh_Regex_t  *re;
+		struct knh_Tuple_t  *tuple;
+		struct knh_Range_t  *range;
+		struct knh_Array_t  *a;
+		struct knh_Iterator_t *it;
+		struct knh_Map_t    *m;
+		struct knh_Func_t         *fo;
+		struct knh_InputStream_t  *in;
+		struct knh_OutputStream_t *w;
+		struct knh_Method_t *mtdOBJ;
+		struct knh_Translator_t *trlOBJ;
+		struct knh_Exception_t *e;
+		struct knh_ExceptionHandler_t *hdr;
+		struct knh_NameSpace_t *ns;
+		struct knh_RawPtr_t   *p;
+		struct knh_ObjectField_t *ox;
+		struct knh_Converter_t *conv;
 	};
 } knh_sfp_t;
 
-#ifdef K_USING_RBP
-typedef struct knh_rbp_t {
-	union {
-		K_FRAME_NCMEMBER;
-		K_FRAME_MEMBER;
-	};
-} knh_rbp_t;
-#else
-typedef struct knh_rbp_t {
-	union {
-		K_FRAME_NCMEMBER;
-	};
-	union {
-		K_FRAME_MEMBER;
-	};
-} knh_rbp_t;
-#endif
+/* ------------------------------------------------------------------------ */
+/* [Context] */
+/* ------------------------------------------------------------------------ */
 
 /* ------------------------------------------------------------------------ */
 /* [ObjectFunc] */
@@ -868,8 +841,6 @@ typedef struct knh_Context_t {
 	knh_mutex_t                  *ctxlock;
 
 	const struct _knh_ExportsAPI_t *api;
-	char                         trace[16];
-	knh_uint_t                   seq;
 } knh_Context_t ;
 
 
