@@ -2,8 +2,8 @@
 #define COMMONS_H_
 
 #define K_INTERNAL
-#include"../../include/konoha07.h"
-#include"../../include/konoha07/konoha_code_.h"
+#include"../../include/konoha.h"
+#include"../../include/konoha/konoha_code_.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -62,7 +62,7 @@ const char* TT__(knh_term_t tt);
 #define TERMs_getcid(stmt, n)   CLASS_type(TERMs_gettype(stmt, n))
 #define TERMs_getbcid(stmt, n)  ctx->share->ClassTBL[TERMs_getcid(stmt,n)].bcid
 
-#define knh_Gamma_setURI(ctx, u)  SP(ctx->gma)->uri  = u
+#define knh_Gamma_setURI(ctx, uri)  SP(ctx->gma)->uri  = uri
 #define knh_Gamma_setLine(ctx, n)   SP(ctx->gma)->line = n
 #define knh_Stmt_flag(ctx, stmt, text, flag) knh_Stmt_flag_(ctx, stmt, STEXT(text), flag)
 
@@ -177,14 +177,7 @@ knh_Token_t* new_TokenTYPED(Ctx *ctx, knh_term_t tt, knh_type_t type, knh_short_
 
 
 /* ------------------------------------------------------------------------ */
-#if defined(K_USING_THREADEDCODE)
-#define TADDR   NULL, 0/*counter*/
-#else
-#define TADDR   0/*counter*/
-#endif/*K_USING_THREADEDCODE*/
 
-#define ASMLINE  0
-/* ------------------------------------------------------------------------ */
 
 #ifdef __cplusplus
 }
