@@ -165,20 +165,7 @@ static knh_bool_t knh_StmtINCLUDE_eval(Ctx *ctx, knh_Stmt_t *stmt, knh_type_t re
 	int isCONTINUE = 1;
 	BEGIN_LOCAL(ctx, lsfp, 1);
 	knh_cwb_t cwbbuf, *cwb = knh_cwb_open(ctx, &cwbbuf);
-	knh_Token_t *t0;
-	knh_String_t *pathS;
-
-	if (DP(stmt)->size != 1) {
-		knh_Gamma_perror(ctx, KERR_ERR, "include file or objectlink");
-		goto L_RETURN;
-	}
-	t0 = DP(stmt)->tokens[0];
-	if (TT_(t0) != TT_NAME && TT_(t0) != TT_STR) {
-		knh_Gamma_perror(ctx, KERR_ERR, "include file or objectlink");
-		goto L_RETURN;
-	}
-	pathS = DP(t0)->text;
-	DBG_ASSERT(IS_String(pathS));
+	knh_String_t *pathS = DP(DP(stmt)->tokens[0])->text;
 	if(S_equals(pathS, STEXT("objectlink"))) {
 		knh_bytes_t path = S_tobytes(knh_getURN(ctx, SP(stmt)->uri));
 		if(path.ustr[0] != '(' && !knh_bytes_startsWith(path, STEXT("http://"))) {
@@ -311,7 +298,7 @@ static int knh_StmtUSINGCLASS_eval(Ctx *ctx, knh_Stmt_t *stmt, size_t n)
 		knh_NameSpace_t *ns = knh_getGammaNameSpace(ctx);
 		int isOVERRIDE = knh_Stmt_flag(ctx, stmt, "Override", 1);
 		if(TT_(tkN) == TT_MUL) {
-			knh_bytes_t pkgname = knh_bytes_last(S_tobytes(DP(tkPKG)->text), 4/* strlen("pkg:") */);
+			knh_bytes_t pkgname = knh_bytes_last(S_tobytes(DP(tkPKG)->text), 8);
 			size_t cid;
 			for(cid = 0; cid < ctx->share->ClassTBLSize; cid++) {
 				if(ClassTBL(cid).lname == NULL) continue;
@@ -644,9 +631,8 @@ static knh_bool_t knh_Stmt_eval(Ctx *ctx, knh_Stmt_t *stmtITR, knh_type_t reqt,
 	knh_bool_t isCONTINUE = 1;
 	BEGIN_LOCAL(ctx, lsfp, 4);
 	knh_Stmt_t *stmt = NULL;
-	knh_uri_t oldURI = SP(ctx->gma)->uri;
 	KNH_SETv(ctx, lsfp[0].o, stmtITR); // lsfp[1] stmtNEXT
-	knh_Gamma_setURI(ctx, SP(stmtITR)->uri);
+	SP(ctx->gma)->uri = SP(stmtITR)->uri;
 	stmt = stmtITR;
 	while(stmt != NULL) {
 		knh_Gamma_setLine(ctx, SP(stmt)->line);
@@ -732,7 +718,7 @@ static knh_bool_t knh_Stmt_eval(Ctx *ctx, knh_Stmt_t *stmtITR, knh_type_t reqt,
 				KNH_SETv(ctx, lsfp[1+1].o, DP(mtd)->kcode);
 				// lsfp[2+1] exception handler
 				lsfp[thisidx+K_PCIDX].pc = NULL;
-				klr_setmtdNC(ctx, lsfp[thisidx+K_MTDIDX], mtd);
+				klr_setcallmtd(ctx, lsfp[thisidx+K_MTDIDX], mtd);
 				KNH_SETv(ctx, lsfp[thisidx].o, scr);
 				klr_setesp(ctx, lsfp + thisidx+1);
 				if(knh_VirtualMachine_run(ctx, lsfp + thisidx, CODE_LAUNCH) == NULL) {
@@ -754,7 +740,6 @@ static knh_bool_t knh_Stmt_eval(Ctx *ctx, knh_Stmt_t *stmtITR, knh_type_t reqt,
 	L_BREAK:;
 	END_LOCAL(ctx, lsfp);
 	knh_Gamma_setLine(ctx, 0);
-	knh_Gamma_setURI(ctx, oldURI);
 	return isCONTINUE;
 }
 
@@ -906,7 +891,7 @@ knh_bool_t knh_load(Ctx *ctx, knh_bytes_t path, knh_type_t reqt, knh_Array_t *re
 
 /* ------------------------------------------------------------------------ */
 
-KNHAPI(int) konoha_load(konoha_t konoha, knh_bytes_t path, int isCompileOnly)
+int konoha_load(konoha_t konoha, knh_bytes_t path, int isCompileOnly)
 {
 	KONOHA_CHECK(konoha, 0);
 	int isCONTINUE;
