@@ -40,7 +40,7 @@
 
 #include"commons.h"
 #define K_USING_TERMCODE
-#include"../../include/konoha07/konoha_grammar_.h"
+#include"../../include/konoha/konoha_grammar_.h"
 #define TT_SIZE TT_LOR   /* |a| */
 
 /* ************************************************************************ */
@@ -340,7 +340,7 @@ void knh_dump_stmt(Ctx *ctx, knh_OutputStream_t *w, knh_Stmt_t *stmt, int isNEXT
 /* ------------------------------------------------------------------------ */
 /* [tokenizer] */
 
-static void knh_Token_add(Ctx *ctx, knh_Token_t *tkB, knh_Token_t *tk);
+static void knh_Token_add(Ctx *ctx, knh_Token_t *tk, knh_Token_t *tkc);
 
 static void knh_InputStream_perror(Ctx *ctx, knh_InputStream_t *in, int pe, const char *fmt, ...)
 {
@@ -387,10 +387,8 @@ knh_Token_t *new_TokenCID(Ctx *ctx, knh_class_t cid)
 static knh_Token_t *new_TokenPTYPE(Ctx *ctx, knh_class_t cid, knh_Token_t *tk)
 {
 	knh_Token_t *tkT = new_Token(ctx, 0, TT_TYPE);
-	knh_Token_t *tkC = new_TokenCID(ctx, cid);
 	knh_Term_setLine(tkT, tk);
-	knh_Term_setLine(tkC, tk);
-	knh_Token_add(ctx, tkT, tkC);
+	knh_Token_add(ctx, tkT, new_TokenCID(ctx, cid));
 	knh_Token_add(ctx, tkT, tk);
 	return tkT;
 }
@@ -417,89 +415,85 @@ static int ITR_findPTYPE(tkitr_t *itr)
 
 static void knh_Token_toStmtTYPEOF(Ctx *ctx, knh_Token_t *tk);
 
-static void knh_Token_add(Ctx *ctx, knh_Token_t *tkB, knh_Token_t *tk)
+static void knh_Token_add(Ctx *ctx, knh_Token_t *tk, knh_Token_t *tkc)
 {
-	int prev = 0;
 	knh_Array_t *a;
 	knh_Token_t *tkPREV;
-	if(SP(tk)->line == 0) {
-		knh_Term_setLine(tk, tkB);
+	int prev = 0;
+	if(SP(tkc)->line == 0) {
+		knh_Term_setLine(tkc, tk);
 	}
-	DBG_ASSERT(SP(tkB)->line != 0 && SP(tk)->line != 0);
-
-	if(IS_NULL(DP(tkB)->data)) {
-		KNH_SETv(ctx, DP(tkB)->data, tk);
+	DBG_ASSERT(SP(tk)->line != 0 && SP(tkc)->line != 0);
+	if(TT_(tkc) == TT_SEMICOLON) {
+		knh_Token_setBOL(tkc, 1);
+	}
+	if(IS_NULL(DP(tk)->data)) {
+		KNH_SETv(ctx, DP(tk)->data, tkc);
 		return;
 	}
-	if(IS_Token(DP(tkB)->data)) {
+
+	if(IS_Token(DP(tk)->data)) {
 		a = new_Array(ctx, CLASS_Any, 2);
-		tkPREV = DP(tkB)->token;
-		knh_Array_add(ctx, a, DP(tkB)->data);
-		KNH_SETv(ctx, DP(tkB)->data, a);
+		tkPREV = DP(tk)->token;
+		knh_Array_add(ctx, a, DP(tk)->data);
+		KNH_SETv(ctx, DP(tk)->data, a);
 	}
 	else {
-		DBG_ASSERT(IS_Array(DP(tkB)->data));
-		a = DP(tkB)->list;
+		DBG_ASSERT(IS_Array(DP(tk)->data));
+		a = DP(tk)->list;
 		DBG_ASSERT(knh_Array_size(a) > 0);
 		prev = knh_Array_size(a)-1;
 		tkPREV = knh_TOKENs_n(a, prev);
 	}
-	knh_Array_add(ctx, a, tk);
-
-	if(TT_(tk) == TT_SEMICOLON) {
-		knh_Token_setBOL(tk, 1); return;
-	}
-	if((SP(tk)->line > SP(tkPREV)->line) && !(knh_Token_isPLUSLINE(tkB))) {
-//		DBG_P("TT='%s' prev_line=%d, line=%d", TT__(TT_(tk)), SP(tkPREV)->line, SP(tk)->line);
-		if(!(TT_(tk) == TT_PARENTHESIS || TT_(tk) == TT_BRACE || TT_(tk) == TT_BRANCET)) {
-			knh_Token_setBOL(tk, 1);  /* a = [1, 2]  multiple */
-		}
-	}
+	knh_Array_add(ctx, a, tkc);
 
 	L_JOIN:;
-	if(TT_isSTR(TT_(tk))) {
+	if(TT_isSTR(TT_(tkc))) {
 		if(TT_isSTR(TT_(tkPREV)) || TT_(tkPREV) == TT_FMTSTR) {
 			knh_cwb_t cwbbuf, *cwb = knh_cwb_open(ctx, &cwbbuf);
 			knh_Bytes_write(ctx, cwb->ba, S_tobytes(DP(tkPREV)->text));
-			if(SP(tk)->line > SP(tkPREV)->line) {
+			if(SP(tkc)->line > SP(tkPREV)->line) {
 				knh_Bytes_putc(ctx, cwb->ba, '\n');
 			}
-			knh_Bytes_write(ctx, cwb->ba, S_tobytes(DP(tk)->text));
+			knh_Bytes_write(ctx, cwb->ba, S_tobytes(DP(tkc)->text));
 			KNH_SETv(ctx, DP(tkPREV)->data, knh_cwb_newString(ctx, cwb));
-			if(TT_(tk) == TT_ESTR) TT_(tkPREV) = TT_ESTR;
+			if(TT_(tkc) == TT_ESTR) TT_(tkPREV) = TT_ESTR;
 			knh_Array_trimSize(ctx, a, prev+1); return;
 		}
 		if(TT_(tkPREV) == TT_NAME && ISB(S_tobytes(DP(tkPREV)->text), "%%")) {
-			TT_(tk) = TT_FMTSTR;
-			KNH_SETv(ctx, a->list[prev], tk);
+			TT_(tkc) = TT_FMTSTR;
+			KNH_SETv(ctx, a->list[prev], tkc);
 			knh_Array_trimSize(ctx, a, prev+1); return;
 		}
 	}
-	if(TT_isSTR(TT_(tk)) && TT_(tkPREV) == TT_URN) {
+	if(TT_isSTR(TT_(tkc)) && TT_(tkPREV) == TT_URN) {
 		knh_cwb_t cwbbuf, *cwb = knh_cwb_open(ctx, &cwbbuf);
 		knh_Bytes_write(ctx, cwb->ba, S_tobytes(DP(tkPREV)->text));
-		knh_Bytes_write(ctx, cwb->ba, S_tobytes(DP(tk)->text));
+		knh_Bytes_write(ctx, cwb->ba, S_tobytes(DP(tkc)->text));
 		KNH_SETv(ctx, DP(tkPREV)->data, knh_cwb_newString(ctx, cwb));
 		knh_Array_trimSize(ctx, a, prev+1); return;
 	}
-	if(TT_(tk) == TT_EXPT && TT_(tkPREV) == TT_UNAME) {
+	if(SP(tkc)->line > SP(tkPREV)->line && TT_(tk) == TT_BRACE) {
+		knh_Token_setBOL(tkc, 1); return;
+	}
+	if(TT_(tkc) == TT_EXPT && TT_(tkPREV) == TT_UNAME) {
 		knh_Token_setExceptionType(tkPREV, 1);
 		knh_Array_trimSize(ctx, a, prev+1); return;
 	}
 	if(isTYPE(tkPREV)) {
-		if(TT_(tk) == TT_ITR) {  // String..
+		if(TT_(tkc) == TT_ITR) {  // String..
 			KNH_SETv(ctx, a->list[prev], new_TokenPTYPE(ctx, CLASS_Iterator, tkPREV));
 			knh_Array_trimSize(ctx, a, prev+1); return;
 		}
-		if(TT_(tk) == TT_BRANCET && IS_NULL(DP(tk)->data)) { // String[]
+		if(TT_(tkc) == TT_BRANCET && IS_NULL(DP(tkc)->data)) { // String[]
 			KNH_SETv(ctx, a->list[prev], new_TokenPTYPE(ctx, CLASS_Array, tkPREV));
 			knh_Array_trimSize(ctx, a, prev+1); return;
 		}
-		if(TT_(tk) == TT_GT || TT_(tk) == TT_RSFT) { // String> or String>>
-			tkitr_t itrbuf, *itr = ITR_new(tkB, &itrbuf);
+		if(TT_(tkc) == TT_GT || TT_(tkc) == TT_RSFT) { // String> or String>>
+			tkitr_t itrbuf, *itr = ITR_new(tk, &itrbuf);
 			if(ITR_findPTYPE(itr)) {
 				knh_Token_t *tkT = new_Token(ctx, 0, TT_TYPE);
-				knh_Term_setLine(tkT, tk);
+				knh_Term_setLine(tkT, tkc);
 				prev = itr->c;
 				while(ITR_hasNext(itr)) {
 					knh_Token_t *tkPT = ITR_nextTK(itr);
@@ -510,10 +504,10 @@ static void knh_Token_add(Ctx *ctx, knh_Token_t *tkB, knh_Token_t *tk)
 					ITR_next(itr);
 				}
 				KNH_SETv(ctx, a->list[prev], tkT);
-				if(TT_(tk) == TT_RSFT) {
-					TT_(tk) = TT_GT;
+				if(TT_(tkc) == TT_RSFT) {
+					TT_(tkc) = TT_GT;
 					tkPREV = tkT;
-					KNH_SETv(ctx, a->list[prev+1], tk);
+					KNH_SETv(ctx, a->list[prev+1], tkc);
 					knh_Array_trimSize(ctx, a, prev+2);
 					goto L_JOIN;
 				}
@@ -522,14 +516,14 @@ static void knh_Token_add(Ctx *ctx, knh_Token_t *tkB, knh_Token_t *tk)
 			}
 		}
 	}
-	if(TT_(tk) == TT_PARENTHESIS) {
+	if(TT_(tkc) == TT_PARENTHESIS) {
 		if(TT_(tkPREV) == TT_TYPEOF) {
 			knh_Token_t *tkT = new_Token(ctx, 0, TT_TYPE);
-			knh_Term_setLine(tkT, tk);
+			knh_Term_setLine(tkT, tkc);
 			knh_Token_add(ctx, tkT, tkPREV);
-			TT_(tk) = TT_BRACE; /* stop recursion */
-			knh_Token_add(ctx, tkT, tk);
-			TT_(tk) = TT_PARENTHESIS;
+			TT_(tkc) = TT_BRACE; /* stop recursion */
+			knh_Token_add(ctx, tkT, tkc);
+			TT_(tkc) = TT_PARENTHESIS;
 			KNH_SETv(ctx, a->list[prev], tkT);
 			knh_Array_trimSize(ctx, a, prev+1);
 			knh_Token_toStmtTYPEOF(ctx, tkT);
@@ -550,10 +544,10 @@ static void knh_Token_add(Ctx *ctx, knh_Token_t *tkB, knh_Token_t *tk)
 	}
 	if(TT_(tkPREV) == TT_BYTE) {
 		TT_(tkPREV) = TT_UNAME;
-		if(TT_(tk) == TT_BRANCET) {
+		if(TT_(tkc) == TT_BRANCET) {
 			knh_Token_setBYTE(tkPREV, 1);
 			KNH_SETv(ctx, DP(tkPREV)->text, ClassTBL(CLASS_Bytes).sname);
-			if(IS_NULL(DP(tk)->data)) { // byte[] => Bytes
+			if(IS_NULL(DP(tkc)->data)) { // byte[] => Bytes
 				knh_Array_trimSize(ctx, a, prev+1);
 			}
 		}
@@ -763,22 +757,19 @@ static void knh_Token_setTEXT(Ctx *ctx, knh_Token_t *tk, knh_cwb_t *cwb)
 	}
 }
 
-#define knh_Token_setLine(tk, in) \
-	SP(tk)->uri  = DP(in)->uri; \
-	SP(tk)->line = DP(in)->line; \
-
-static void knh_Token_addBuf(Ctx *ctx, knh_Token_t *tkB, knh_cwb_t *cwb, knh_term_t tt, int ch)
+static void knh_Token_addBuf(Ctx *ctx, knh_Token_t *tk, knh_cwb_t *cwb, knh_term_t tt, int ch)
 {
 	if(knh_cwb_size(cwb) != 0) {
-		knh_Token_t *newtk = new_Token(ctx, 0, tt);
+		knh_flag_t flag = 0;
+		knh_Token_t *newtk = new_Token(ctx, flag, tt);
 		knh_Token_setTEXT(ctx, newtk, cwb);
-		knh_Token_add(ctx, tkB, newtk);
+		knh_Token_add(ctx, tk, newtk);
 		knh_cwb_clear(cwb, 0);
 	}
 	else if(tt == TT_BLOCK || TT_isSTR(tt) || tt == TT_REGEX) {
 		knh_Token_t *newtk = new_Token(ctx, 0, tt);
 		KNH_SETv(ctx, DP(newtk)->data, TS_EMPTY);
-		knh_Token_add(ctx, tkB, newtk);
+		knh_Token_add(ctx, tk, newtk);
 	}
 }
 
@@ -792,7 +783,7 @@ static void knh_InputStream_skipLINECOMMENT(Ctx *ctx, knh_InputStream_t *in)
 
 static void knh_InputStream_skipBLOCKCOMMENT(Ctx *ctx, knh_InputStream_t *in, knh_Bytes_t *ba)
 {
-	int ch, prev = '*', level = 1;
+	int ch, prev = '/', level = 1;
 	while((ch = knh_InputStream_getc(ctx, in)) != EOF) {
 		if(prev == '*' && ch == '/') {
 			level--;
@@ -818,9 +809,11 @@ static knh_bool_t knh_Bytes_isTupleQuote(knh_Bytes_t *ba, int quote)
 static void knh_Bytes_addEscapeSequence(Ctx *ctx, knh_Bytes_t *ba, knh_InputStream_t *in)
 {
 	int ch = knh_InputStream_getc(ctx, in);
-	if(ch == 'n')      ch = '\n';
-	else if(ch == 't') ch = '\t';
-	else if(ch == 'r') ch = '\r';
+	if(ch == 'n') {
+		ch = '\n';
+	}else if(ch == 't') {
+		ch = '\t';
+	}
 	knh_Bytes_putc(ctx, ba, ch);
 }
 
@@ -1009,7 +1002,6 @@ static int knh_Token_addOPR(Ctx *ctx, knh_Token_t *tk, knh_cwb_t *cwb, knh_Input
 			return knh_InputStream_getc(ctx, in);
 		}else if(ch == '/') {
 			knh_InputStream_skipLINECOMMENT(ctx, in);
-			knh_Token_setLine(tk, in);
 			return knh_InputStream_getc(ctx, in);
 		}
 		if(knh_Token_startsWithExpr(ctx, tk)) {
@@ -1158,30 +1150,68 @@ static int knh_Token_addNUM(Ctx *ctx, knh_Token_t *tk, knh_cwb_t *cwb, knh_Input
 	return ch;
 }
 
-static void knh_Token_addBLOCKERR(Ctx *ctx, knh_Token_t *tk, knh_InputStream_t *in)
-{
-	knh_Token_t *tkERR = new_Token(ctx, 0, TT_ERR);
-	knh_Token_setLine(tkERR, in);
-	knh_InputStream_perror(ctx, in, KERR_ERR, "forgot? }");
-	knh_Token_add(ctx, tk, tkERR);
-}
+#define IBUFSIZ 80
 
-static void knh_Token_addBLOCK(Ctx *ctx, knh_Token_t *tk, knh_cwb_t *cwb, knh_InputStream_t *in, int block_indent)
+//static void knh_dump_ibuf(char *ibuf)
+//{
+//	fprintf(stderr, "ibuf: '");
+//	while(*ibuf != 0) {
+//		if(*ibuf == ' ') fputc('s', stderr); else fputc('t', stderr);
+//		ibuf++;
+//	}
+//	fprintf(stderr, "'\n");
+//}
+
+static void knh_Token_addBLOCK(Ctx *ctx, knh_Token_t *tk, knh_cwb_t *cwb, knh_InputStream_t *in, char *begin_ibuf)
 {
-	int ch, prev = '{', level = 1;
+	int ch, prev = '{', indent_pos = -1, level = 1;
+	char indent_buf[IBUFSIZ];
 	knh_Token_addBuf(ctx, tk, cwb, TT_CODE, '{');
+//	knh_dump_ibuf(begin_ibuf);
+	goto L_START;
+
+	L_NEWLINE:
+	indent_pos = 0;
+	knh_bzero(indent_buf, IBUFSIZ);
+	while((ch = knh_InputStream_getc(ctx, in)) != EOF) {
+		if(ch == '\t' || ch == ' ' || ch == '\v') {
+			indent_buf[indent_pos] = ch;
+			if(indent_pos < IBUFSIZ - 1) indent_pos++;
+			continue;
+		}
+		break;
+	}
+//	knh_dump_ibuf(indent_buf);
+	/*if(ch != '}')*/ { /* indent normization */
+		int i, isize = level - ((ch != '}') ? 1 : 2);
+		for(i = 0; i < isize; i++) {
+			knh_Bytes_putc(ctx, cwb->ba, '\t');
+		}
+	}
+	goto L_STARTLINE;
+	L_START:;
 	while((ch = knh_InputStream_getc(ctx, in)) != EOF) {
 		L_STARTLINE:;
 		if(ch == '}' && prev != '\\') {
 			level--;
-			if(level == 0) {
-				knh_Token_addBuf(ctx, tk, cwb, TT_BLOCK, ch);
-				return;
-			}
+			if(level == 0) break;
+//			if(indent_pos != -1) {
+//				int i;
+//				for(i = 0; i < indent_pos; i++) {
+//					//if(begin_ibuf[i] == 0) goto L_OK;
+//					DBG_P("i=%d, '%c', '%c'", i, _S(begin_ibuf[i]), _S(indent_buf[i]));
+//					if(begin_ibuf[i] != indent_buf[i]) {
+//						goto L_OK;
+//					}
+//				}
+//				knh_InputStream_perror(ctx, in, KERR_DWARN, _("mismatch indent"));
+//				break;
+//			}
 		}
+//		L_OK:;
 		knh_Bytes_putc(ctx, cwb->ba, ch);
 		if(ch == '\n') {
-			break;
+			goto L_NEWLINE;
 		}
 		else if(ch == '{' && prev != '\\') {
 			level++;
@@ -1201,135 +1231,113 @@ static void knh_Token_addBLOCK(Ctx *ctx, knh_Token_t *tk, knh_cwb_t *cwb, knh_In
 		}
 		prev = ch;
 	}
-	/*NEWLINE*/{
-		int c = 0;
-		while((ch = knh_InputStream_getc(ctx, in)) != EOF) {
-			if(ch == '\t') { c += 3; }
-			else if(ch == ' ') { c += 1; }
-			else {
-				if(block_indent <= c) {
-					goto L_STARTLINE;
-				}
-			}
-		}
-	}
-	knh_cwb_clear(cwb, 0);
-	knh_Token_addBLOCKERR(ctx, tk, in);
+	knh_Token_addBuf(ctx, tk, cwb, TT_BLOCK, ch);
 }
 
-static void knh_InputStream_parseToken(Ctx *ctx, knh_InputStream_t *in, knh_Token_t *tkB)
+#define knh_Token_setLine(tk, in) \
+	SP(tk)->uri  = DP(in)->uri; \
+	SP(tk)->line = DP(in)->line; \
+
+static void knh_InputStream_parseToken(Ctx *ctx, knh_InputStream_t *in, knh_Token_t *tk)
 {
-	int ch;
-	int block_indent = 0, block_line = 0;
+	int ch, indent_pos;
 	knh_cwb_t cwbbuf, *cwb = knh_cwb_open(ctx, &cwbbuf);
+	char indent_buf[IBUFSIZ];
 	DBG_ASSERT(DP(in)->line != 0);
+
 	L_NEWLINE:;
-	{
-		int c = 0;
-		knh_Token_setLine(tkB, in);
-		knh_Token_setPLUSLINE(tkB, 0);
-		while((ch = knh_InputStream_getc(ctx, in)) != EOF) {
-			if(ch == '\t') { c += 3; }
-			else if(ch == ' ') { c += 1; }
-			else {
-				if(block_line == 0) {
-					block_indent = c;
-				}
-				else {
-					if(block_indent < c) {
-						DBG_P("indent %d < %d", block_indent, c);
-						knh_Token_setPLUSLINE(tkB, 1);
-					}
-					else if(c < block_indent) {
-						knh_Token_addBLOCKERR(ctx, tkB, in);
-						return;
-					}
-				}
-				block_line += 1;
-				goto L_AGAIN;
-			}
+	knh_Token_setLine(tk, in);
+	indent_pos = 0;
+	knh_bzero(indent_buf, IBUFSIZ);
+	while((ch = knh_InputStream_getc(ctx, in)) != EOF) {
+		if(ch == '\t' || ch == ' ' || ch == '\v') {
+			indent_buf[indent_pos] = ch;
+			if(indent_pos < IBUFSIZ - 1) indent_pos++;
+			continue;
 		}
+		goto L_AGAIN;
 	}
 	L_NEWTOKEN:;
 	knh_cwb_clear(cwb, 0);
-	knh_Token_setLine(tkB, in);
+	knh_Token_setLine(tk, in);
 	while((ch = knh_InputStream_getc(ctx, in)) != EOF) {
 		L_AGAIN:;
 		switch(ch) {
+		/* grammatic structure */
 		case '\n':
-			knh_Token_addBuf(ctx, tkB, cwb, TT_CODE, ch);
+			knh_Token_addBuf(ctx, tk, cwb, TT_CODE, ch);
 			goto L_NEWLINE;
 
 		case ' ': case '\t': case '\v': case '\r':
-			knh_Token_addBuf(ctx, tkB, cwb, TT_CODE, ch);
+			knh_Token_addBuf(ctx, tk, cwb, TT_CODE, ch);
 			goto L_NEWTOKEN;
 
 		case ';': case ',':
-			knh_Token_addBuf(ctx, tkB, cwb, TT_CODE, ch);
+			knh_Token_addBuf(ctx, tk, cwb, TT_CODE, ch);
 			knh_Bytes_putc(ctx, cwb->ba, ch);
-			knh_Token_addBuf(ctx, tkB, cwb, TT_CODE, ch);
+			knh_Token_addBuf(ctx, tk, cwb, TT_CODE, ch);
 			goto L_NEWTOKEN;
 
 		case '{':
-			knh_Token_addBLOCK(ctx, tkB, cwb, in, block_indent);
+			knh_Token_addBLOCK(ctx, tk, cwb, in, indent_buf);
 			goto L_NEWTOKEN;
 
 		case '[': case '(':
-			knh_Token_addBuf(ctx, tkB, cwb, TT_CODE, ch);
+			knh_Token_addBuf(ctx, tk, cwb, TT_CODE, ch);
 			{
 				knh_Token_t *ctk = new_Token(ctx, 0, TT_ch(ch));
-				ctk->h.meta = tkB;
-				tkB = ctk;
+				ctk->h.meta = tk;
+				tk = ctk;
 			}
 			goto L_NEWTOKEN;
 
 		case ')': case ']':
-			knh_Token_addBuf(ctx, tkB, cwb, TT_CODE, ch);
-			if(TT_ch(ch) == TT_(tkB)) {
-				knh_Token_t *ctk = tkB;
-				tkB = (knh_Token_t*)(ctk)->h.meta;
+			knh_Token_addBuf(ctx, tk, cwb, TT_CODE, ch);
+			if(TT_ch(ch) == TT_(tk)) {
+				knh_Token_t *ctk = tk;
+				tk = (knh_Token_t*)(ctk)->h.meta;
 				(ctk)->h.meta = NULL;
-				knh_Token_add(ctx, tkB, ctk);
-				knh_Term_setLine(ctk, tkB);
-				knh_Token_setLine(tkB, in);
+				knh_Token_add(ctx, tk, ctk);
+				knh_Term_setLine(ctk, tk);
+				knh_Token_setLine(tk, in);
 				goto L_NEWTOKEN;
 			}
 		case '}':
-			knh_Token_addBuf(ctx, tkB, cwb, TT_CODE, ch);
+			knh_Token_addBuf(ctx, tk, cwb, TT_CODE, ch);
 			knh_InputStream_perror(ctx, in, KERR_ERR, "mismatched %c", ch);
 			goto L_NEWTOKEN;
 
 		/* token */
 		case '"': case '\'': case '`' :
 		case '#':
-			ch = knh_Token_addQUOTE(ctx, tkB, cwb, in, ch, 0/*isRAW*/);
+			ch = knh_Token_addQUOTE(ctx, tk, cwb, in, ch, 0/*isRAW*/);
 			goto L_AGAIN;
 
 		case '$':
-			ch = knh_Token_addPROPN(ctx, tkB, cwb, in);
+			ch = knh_Token_addPROPN(ctx, tk, cwb, in);
 			goto L_AGAIN;
 		case '@':
-			ch = knh_Token_addMETAN(ctx, tkB, cwb, in);
+			ch = knh_Token_addMETAN(ctx, tk, cwb, in);
 			goto L_AGAIN;
 		case '|':
 #ifdef TT_SIZE
-			knh_Token_addBuf(ctx, tkB, cwb, TT_CODE, ch);
-			if(TT_ch(ch) == TT_(tkB)) {
-				knh_Token_t *ctk = tkB;
-				tkB = (knh_Token_t*)(ctk)->h.meta;
+			knh_Token_addBuf(ctx, tk, cwb, TT_CODE, ch);
+			if(TT_ch(ch) == TT_(tk)) {
+				knh_Token_t *ctk = tk;
+				tk = (knh_Token_t*)(ctk)->h.meta;
 				(ctk)->h.meta = NULL;
-				knh_Token_add(ctx, tkB, ctk);
-				knh_Term_setLine(ctk, tkB);
-				knh_Token_setLine(tkB, in);
+				knh_Token_add(ctx, tk, ctk);
+				knh_Term_setLine(ctk, tk);
+				knh_Token_setLine(tk, in);
 				TT_(ctk) = TT_PARENTHESIS;
 				knh_Bytes_write(ctx, cwb->ba, STEXT(".size"));
-				knh_Token_addBuf(ctx, tkB, cwb, TT_CODE, ' ');
+				knh_Token_addBuf(ctx, tk, cwb, TT_CODE, ' ');
 				goto L_NEWTOKEN;
 			}
-			if(knh_Token_startsWithExpr(ctx, tkB)) {
+			if(knh_Token_startsWithExpr(ctx, tk)) {
 				knh_Token_t *ctk = new_Token(ctx, 0, TT_ch(ch));
-				ctk->h.meta = tkB;
-				tkB = ctk;
+				ctk->h.meta = tk;
+				tk = ctk;
 				goto L_NEWTOKEN;
 			}
 #endif
@@ -1337,28 +1345,28 @@ static void knh_InputStream_parseToken(Ctx *ctx, knh_InputStream_t *in, knh_Toke
 			knh_bytes_t t = knh_cwb_tobytes(cwb);
 			if(ISB(t, "in") || ISB(t, "isa") || ISB(t, "is")) {
 				knh_Bytes_putc(ctx, cwb->ba, ch);
-				knh_Token_addBuf(ctx, tkB, cwb, TT_CODE, ' ');
+				knh_Token_addBuf(ctx, tk, cwb, TT_CODE, ' ');
 				break;
 			}
 		}
 		case '+': case '-': case '*': case '/': case '%':
 		case '=': case '&':
 		case '<': case '>': case '^': case '!': case '~':
-			knh_Token_addBuf(ctx, tkB, cwb, TT_CODE, ch);
-			ch = knh_Token_addOPR(ctx, tkB, cwb, in, ch);
+			knh_Token_addBuf(ctx, tk, cwb, TT_CODE, ch);
+			ch = knh_Token_addOPR(ctx, tk, cwb, in, ch);
 			goto L_AGAIN;
 
 		case '.':
-			knh_Token_addBuf(ctx, tkB, cwb, TT_CODE, '.');
+			knh_Token_addBuf(ctx, tk, cwb, TT_CODE, '.');
 			ch = knh_InputStream_getc(ctx, in);
 			if(ch == '.') {
 				knh_Bytes_putc(ctx, cwb->ba, '.');
-				ch = knh_Token_addOPR(ctx, tkB, cwb, in, ch);
+				ch = knh_Token_addOPR(ctx, tk, cwb, in, ch);
 			}
 			else if(isdigit(ch)) {
 				knh_Bytes_putc(ctx, cwb->ba, '0');
 				knh_Bytes_putc(ctx, cwb->ba, '.');
-				ch = knh_Token_addNUM(ctx, tkB, cwb, in, ch);
+				ch = knh_Token_addNUM(ctx, tk, cwb, in, ch);
 			}
 			else {
 				knh_Bytes_putc(ctx, cwb->ba, '.');
@@ -1366,7 +1374,7 @@ static void knh_InputStream_parseToken(Ctx *ctx, knh_InputStream_t *in, knh_Toke
 			goto L_AGAIN;
 
 		case ':':
-			ch = knh_Token_addURN(ctx, tkB, cwb, in);
+			ch = knh_Token_addURN(ctx, tk, cwb, in);
 			goto L_AGAIN;
 
 		case EOF :
@@ -1375,7 +1383,7 @@ static void knh_InputStream_parseToken(Ctx *ctx, knh_InputStream_t *in, knh_Toke
 		case '0': case '1': case '2': case '3': case '4':
 		case '5': case '6': case '7': case '8': case '9':
 			if(knh_cwb_size(cwb) == 0) {
-				ch = knh_Token_addNUM(ctx, tkB, cwb, in, ch);
+				ch = knh_Token_addNUM(ctx, tk, cwb, in, ch);
 				goto L_AGAIN;
 			}
 
@@ -1386,8 +1394,9 @@ static void knh_InputStream_parseToken(Ctx *ctx, knh_InputStream_t *in, knh_Toke
 			}
 			knh_Bytes_putc(ctx, cwb->ba, ch);
 		} /* switch */
+
 	}/*while*/
-	knh_Token_addBuf(ctx, tkB, cwb, TT_CODE, EOF);
+	knh_Token_addBuf(ctx, tk, cwb, TT_CODE, EOF);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -1577,8 +1586,7 @@ static tkitr_t *ITR_stmt(Ctx *ctx, tkitr_t *itr, int pos, tkitr_t *buf, int isNe
 	}
 	buf->e = itr->e;
 	itr->c = itr->e;
-	if(isNeedSemicolon && 
-			(itr->e -1 >= 0 && TT_(itr->ts[itr->e-1]) != TT_SEMICOLON)) {
+	if(isNeedSemicolon && itr->e -1 >= 0) {
 		knh_Token_perror(ctx, itr->ts[itr->e - 1], KERR_BAD, "needs ;");
 	}
 	return buf;
@@ -2951,10 +2959,10 @@ static knh_Stmt_t *new_StmtMETA(Ctx *ctx, knh_term_t stt, tkitr_t *itr, int shif
 {
 	knh_Fstmt func = NULL;
 	va_list ap;
-	va_start(ap , shift);
 	knh_Stmt_t *stmt = new_Stmt2(ctx, stt, NULL);
 	knh_Stmt_addMETA(ctx, stmt, itr);
 	itr->c = itr->c + shift;
+	va_start(ap , shift);
 	while((func = (knh_Fstmt)va_arg(ap, knh_Fstmt)) != NULL) {
 		if(STT_(stmt) == STT_ERR) {
 			return stmt;
@@ -3186,10 +3194,10 @@ knh_Stmt_t *knh_InputStream_parseStmt(Ctx *ctx, knh_InputStream_t *in)
 knh_Stmt_t *knh_Token_parseStmt(Ctx *ctx, knh_Token_t *tk)
 {
 	knh_Stmt_t *rVALUE = new_Stmt2(ctx, STT_BLOCK, NULL);
-	BEGIN_LOCAL(ctx, lsfp, 1);
-	KNH_SETv(ctx, lsfp[0].o, rVALUE);
 	knh_Token_toBLOCK(ctx, tk);
 	knh_Term_setLine(rVALUE, tk);
+	BEGIN_LOCAL(ctx, lsfp, 1);
+	KNH_SETv(ctx, lsfp[0].o, rVALUE);
 	if(TT_(tk) != TT_ERR) {
 		tkitr_t tbuf, *titr = ITR_new(tk, &tbuf);
 		_STMTs(ctx, rVALUE, titr);
