@@ -56,7 +56,7 @@ static METHOD Map_get(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
 	knh_Map_t *m = sfp[0].m;
 	if(!m->dspi->get(ctx, m->dmap, sfp + 1, sfp + rix)) {
-		RETURNa_(KNH_NULVAL(knh_class_p2(knh_Object_cid(m))));
+		RETURN_(KNH_NULVAL(knh_class_p1(knh_Object_cid(sfp[0].o))));
 	}
 }
 
@@ -80,25 +80,33 @@ static METHOD DictMap_remove(Ctx *ctx, knh_sfp_t *sfp, long rix)
 	RETURNvoid_();
 }
 
-/* ------------------------------------------------------------------------ */
-//## method T1.. Map.keys();
+///* ------------------------------------------------------------------------ */
+////## method T1[] Map.keys();
+//
+//static METHOD Map_keys(Ctx *ctx, knh_sfp_t *sfp, long rix)
+//{
+//	knh_DictMap_t *o = (knh_DictMap_t*)sfp[0].o;
+//	knh_Array_t *a = new_Array(ctx, CLASS_String, o->size);
+//	size_t i;
+//	for(i=0; i < o->size; i++) {
+//		knh_Array_add_(ctx, a, UPCAST(o->list[i].key));
+//	}
+//	RETURN_(UPCAST(a));
+//}
 
-static METHOD Map_keys(Ctx *ctx, knh_sfp_t *sfp, long rix)
-{
-	knh_Map_t *m = sfp[0].m;
-	knh_Iterator_t *itr = m->dspi->toIterator(ctx, m, MAPITR_KEY);
-	RETURN_(itr);
-}
-
-/* ------------------------------------------------------------------------ */
-//## method T1.. Map.values();
-
-static METHOD Map_values(Ctx *ctx, knh_sfp_t *sfp, long rix)
-{
-	knh_Map_t *m = sfp[0].m;
-	knh_Iterator_t *itr = m->dspi->toIterator(ctx, m, MAPITR_VALUE);
-	RETURN_(itr);
-}
+///* ------------------------------------------------------------------------ */
+////## method T1[] Map.values();
+//
+//static METHOD Map_values(Ctx *ctx, knh_sfp_t *sfp, long rix)
+//{
+//	knh_DictMap_t *o = (knh_DictMap_t*)sfp[0].o;
+//	knh_Array_t *a = new_Array0(ctx, o->size);
+//	size_t i;
+//	for(i=0; i < o->size; i++) {
+//		knh_Array_add_(ctx, a, UPCAST(o->list[i].value));
+//	}
+//	RETURN_(UPCAST(a));
+//}
 
 /* ------------------------------------------------------------------------ */
 
