@@ -37,7 +37,6 @@ extern "C" {
 
 #ifdef K_USING_DEFAULTAPI
 
-#define knh_DictMap_removeAt(ctx, d, n) knh_DictMap_set(ctx, d, knh_DictMap_keyAt(d, n), KNH_NULL)
 /* ------------------------------------------------------------------------ */
 /* [format] */
 
@@ -122,7 +121,7 @@ static knh_bool_t _isRecuriveFormatting(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_sfp_t *sp = sfp - 3;
 	while(ctx->stack < sp) {
-		if(sp[0].mtdNC == sfp[0].mtdNC && sp[1].w == sfp[1].w && sp[2].o == sfp[2].o) {
+		if(sp[0].callmtd == sfp[0].callmtd && sp[1].w == sfp[1].w && sp[2].o == sfp[2].o) {
 			return 1;
 		}
 		sp--;
@@ -138,9 +137,9 @@ static void knh_stack_reformat(Ctx *ctx, knh_sfp_t *sfp, knh_methodn_t fmt)
 
 static knh_ndata_t knh_Object_ndata(void *p)
 {
-	//if(sizeof(knh_bool_t) < sizeof(knh_ndata_t)) {
-	//	return ((knh_bool_t*)p)[0];
-	//}
+	if(sizeof(knh_bool_t) < sizeof(knh_ndata_t)) {
+		return ((knh_bool_t*)p)[0];
+	}
 	if(sizeof(knh_int_t) < sizeof(knh_ndata_t)) {
 		return ((knh_int_t*)p)[0];
 	}
@@ -408,40 +407,20 @@ static METHOD Iterator__k(Ctx *ctx, knh_sfp_t *sfp, long rix)
 	}
 }
 
-/* ------------------------------------------------------------------------ */
-//## method void Tuple.%k();
-
-static METHOD Tuple__k(Ctx *ctx, knh_sfp_t *sfp, long rix)
-{
-	knh_Tuple_t *o = sfp[1].tuple;
-	knh_OutputStream_t *w = WWW;
-	knh_putc(ctx, w, '(');
-	knh_Method_t *mtdf = knh_getSystemFormatter(ctx, knh_Object_p1(o), MN__k);
-	if(_isRecuriveFormatting(ctx, sfp)) {
-		knh_write_dots(ctx,w);
-	}
-	else if(knh_Tuple_isTriple(o)) {
-		knh_write_Object(ctx, w, sfp+4, &mtdf, o->first);
-		knh_write_delim(ctx,w);
-		knh_write_Object(ctx, w, sfp+4, &mtdf, o->second);
-		if (o->thirdNULL && IS_NOTNULL(o->thirdNULL)) {
-			knh_write_delim(ctx,w);
-			knh_write_Object(ctx, w, sfp+4, &mtdf, o->thirdNULL);
-		}
-	}
-	else {
-		size_t i;
-		for(i = 0; i < o->size; i++) {
-			if(i > 0) {
-				knh_write_delim(ctx,w);
-			}
-			knh_write_Object(ctx, w, sfp+4, &mtdf, o->list[i]);
-		}
-	}
-
-	knh_putc(ctx, w, ')');
-}
-
+///* ------------------------------------------------------------------------ */
+////## method void Tuple.%k();
+//
+//static METHOD Tuple__k(Ctx *ctx, knh_sfp_t *sfp, long rix)
+//{
+////	knh_Tuple_t *o = sfp[1].tuple;
+//	knh_OutputStream_t *w = WWW;
+//	knh_putc(ctx, w, '(');
+//	if(_isRecuriveFormatting(ctx, sfp)) {
+//		knh_write_dots(ctx,w);
+//	}
+//	knh_putc(ctx, w, ')');
+//}
+//
 ///* ------------------------------------------------------------------------ */
 ////## method void Range.%k();
 //
@@ -480,12 +459,6 @@ static METHOD Array__k(Ctx *ctx, knh_sfp_t *sfp, long rix)
 				knh_write_ffmt(ctx, w, K_FLOAT_FMT, a->flist[c]);
 			}
 		}
-		else if(IS_Tbool(p1)) {
-			for(c = 0; c < knh_Array_size(a); c++) {
-				if(c > 0) knh_write_delim(ctx, w);
-				knh_write_bool(ctx, w, a->ilist[c]);
-			}
-		}
 		else if(knh_Array_size(a) > 0) {
 			knh_Method_t *mtd = knh_getSystemFormatter(ctx, knh_Object_cid(a->list[0]), MN__k);
 			for(c = 0; c < knh_Array_size(a); c++) {
@@ -497,40 +470,32 @@ static METHOD Array__k(Ctx *ctx, knh_sfp_t *sfp, long rix)
 	knh_putc(ctx, w, ']');
 }
 
-#define knh_Map_size(o) ((o)->dspi->size(ctx, o->map))
 /* ------------------------------------------------------------------------ */
 //## method void Map.%k();
 
 static METHOD Map__k(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	knh_OutputStream_t *w = WWW;
-	knh_putc(ctx, w, '{');
-	if(_isRecuriveFormatting(ctx, sfp)) {
-		knh_write_dots(ctx, w);
-	}
-	else {
-		knh_Map_t *o = (knh_Map_t*) sfp[1].o;
-		knh_class_t cid = knh_Object_cid(o);
-		knh_Method_t *mtdf = knh_getSystemFormatter(ctx, knh_class_p1(cid), MN__k);
-		/* TODO set p2's format
-		 *knh_Method_t *mtdf = knh_getSystemFormatter(ctx, knh_class_p1(cid), MN__k);
-		 */
-		if(IS_NOTNULL(o) && knh_Map_size(o) > 0) {
-			knh_Iterator_t *itr = new_Iterator(ctx, CLASS_Tuple, UPCAST(o), NULL);
-			BEGIN_LOCAL(ctx, lsfp, 2);
-			KNH_SETv(ctx, lsfp[0].o, itr);
-			o->dspi->setIterator(ctx, o->map, itr);
-			int c = 0;
-			while(itr->fnext_1(ctx, lsfp, 1)) {
-				knh_Tuple_t *t = (knh_Tuple_t*) lsfp[1].o;
-				if (c > 0) knh_putc(ctx, w, ',');
-				knh_write_Object(ctx, w, sfp+4, &mtdf, UPCAST(t));
-				c++;
-			}
-			END_LOCAL(ctx, lsfp);
-		}
-	}
-	knh_putc(ctx, w, '}');
+	KNH_TODO(__FUNCTION__);
+//	knh_OutputStream_t *w = WWW;
+//	knh_putc(ctx, w, '{');
+//	if(knh_stack_isRecuriveFormatting(ctx, sfp)) {
+//		knh_write_dots(ctx, w);
+//	}
+//	else {
+//		knh_DictMap_t *o = sfp[1].dmap;
+//		knh_DictMap_sort(o);
+//		if(knh_DictMap_size(o) > 0) {
+//			size_t c;
+//			knh_Method_t *mtd = knh_getSystemFormatter(ctx, knh_Object_cid(o->list[0].value), MN__k);
+//			for(c = 0; c < o->size; c++) {
+//				if(c > 0) knh_write_delim(ctx, w);
+//				knh_write(ctx, w, S_tobytes(o->list[c].key));
+//				knh_putc(ctx, w, ':');	knh_putc(ctx, w, ' ');
+//				knh_write_Object(ctx, w, ctx->esp, &mtd, o->list[c].value);
+//			}
+//		}
+//	}
+//	knh_putc(ctx, w, '}');
 }
 
 /* ------------------------------------------------------------------------ */
@@ -893,170 +858,170 @@ static METHOD Exception__dump(Ctx *ctx, knh_sfp_t *sfp, long rix)
 	knh_write_EOL(ctx, w);
 }
 
-/* ======================================================================== */
-/* [man] */
-
-static const char *knh_methodop__tochar(knh_methodn_t mn)
-{
-	switch(mn) {
-	case MN_opNOT: return "!x";
-	case MN_opOF: return "x instanceof T";
-
-	case MN_opHAS:  return "y in x";
-	case MN_opIS:  return "x is y";
-//	case MN_opAs:  return "x as y";
-//	case MN_opInto:  return "x into y";
-
-	case MN_opEQ:  return "x == y";
-	case MN_opNOTEQ:  return "x != y";
-	case MN_opLT:  return "x < y";
-	case MN_opLTE:  return "x <= y";
-	case MN_opGT:  return "x > y";
-	case MN_opGTE:  return "x >= y";
-
-	case MN_opLSFT:  return "x << y";
-	case MN_opSEND:  return "x << y";
-	case MN_opRSFT:  return "x >> y";
-
-	case MN_opMOD:  return "x mod y";
-
-	case MN_opADD:  return "x + y";
-	case MN_opNEG:  return "-x";
-	case MN_opSUB:  return "x - y";
-	case MN_opDIV:  return "x / y";
-	case MN_opMUL:  return "x * y";
-
-	case MN_opLOR:        return "x & y";
-	case MN_opLAND:       return "x | y";
-	case MN_opLNOT:       return "~x";
-	case MN_opLXOR:        return "x ^ y";
-	case MN_opNEXT:       return "x++";
-	case MN_opPREV:       return "x--";
-	case MN_opITR:        return "x..";
-	case MN_getSize:      return "|x|";
-	case MN_get:          return "x[n]";
-	case MN_set:          return "x[n]=y";
-	case MN_setAll:       return "x[]=y";
-	case MN_opTO:    return "x[m to n]";
-	case MN_opUNTIL: return "x[m until n]";
-	case MN_opEXPAND:          return "a,b = x";
-	}
-	return NULL;
-}
-
-static void knh_ClassNAME__man(Ctx *ctx, knh_class_t cid, knh_OutputStream_t *w)
-{
-	knh_write(ctx, w, STEXT("Class"));
-	knh_write_EOL(ctx, w);
-
-	knh_write_TAB(ctx, w);
-	knh_write_ltype(ctx, w, cid);
-	knh_write_EOL(ctx, w);
-
-	while(ClassTBL(cid).supcid != CLASS_Object) {
-		cid = ClassTBL(cid).supcid;
-		knh_write_TAB(ctx, w);
-		knh_write(ctx, w, STEXT("extends "));
-		knh_write_ltype(ctx, w, cid);
-		knh_write_EOL(ctx, w);
-	}
-}
-
-static void knh_ClassCONST__man(Ctx *ctx, knh_class_t cid, knh_OutputStream_t *w)
-{
-	DBG_ASSERT_cid(cid);
-	if(ClassTBL(cid).constDictCaseMapNULL == NULL) return ;
-	knh_DictCaseMap_t *tcmap = ClassTBL(cid).constDictCaseMapNULL;
-	size_t i, size = knh_DictMap_size(tcmap);
-	OLD_LOCK(ctx, LOCK_SYSTBL, NULL);
-	int hasCaption = 0;
-	for(i = 0; i < size; i++) {
-		if(!hasCaption) {
-			knh_write_text(ctx, w, _("Const"));
-			knh_write_EOL(ctx, w);
-			hasCaption = 1;
-		}
-		knh_printf(ctx, w, "\t%s.%s: %O\n", CLASS__(cid),
-				S_tochar(knh_DictCaseMap_keyAt(tcmap, i)),
-				knh_DictCaseMap_valueAt(tcmap, i));
-	}
-	OLD_UNLOCK(ctx, LOCK_SYSTBL, NULL);
-}
-
-
-static void knh_Method__man(Ctx *ctx, knh_Method_t *o, knh_OutputStream_t *w, knh_class_t cid)
-{
-	if(!knh_Context_isVerbose(ctx)) {
-		if(knh_Method_isPrivate(o)) return;
-	}
-
-	if(knh_Method_isAbstract(o)) {
-		knh_write(ctx, w, STEXT("@Abstract"));
-		knh_putc(ctx, w, ' ');
-	}
-
-	knh_write_type(ctx, w, knh_type_tocid(ctx, knh_ParamArray_rtype(DP(o)->mp), cid));
-	knh_putc(ctx, w, ' ');
-
-	if(knh_Method_isStatic(o)) {
-		knh_write_text(ctx, w, CLASS__(cid));
-		knh_putc(ctx, w, '.');
-	}
-	knh_write_mn(ctx, w, DP(o)->mn);
-
-	knh_putc(ctx, w, '(');
-	size_t i;
-	for(i = 0; i < knh_Method_psize(o); i++) {
-		knh_param_t *p = knh_ParamArray_get(DP(o)->mp, i);
-		if(i > 0) {
-			knh_write_delim(ctx, w);
-		}
-		knh_write_type(ctx, w, knh_type_tocid(ctx, p->type, cid));
-		knh_putc(ctx, w, ' ');
-		knh_write(ctx, w, B(FN__(p->fn)));
-	}
-	if(knh_ParamArray_isVARGs(DP(o)->mp)) {
-		knh_write_delim(ctx, w);
-		knh_write_dots(ctx, w);
-	}
-	knh_putc(ctx, w, ')');
-}
-
-static void knh_ClassMap__man(Ctx *ctx, knh_Array_t *tmaps, knh_OutputStream_t *w, knh_class_t cid)
-{
-	size_t i;
-	int hasCaption = 0, from = 0;
-	L_TAIL:;
-	for(i = 0; i < tmaps->size; i++) {
-		if(hasCaption == 0) {
-			knh_write_text(ctx, w, _("Translator"));
-			knh_write_EOL(ctx, w);
-			hasCaption = 1;
-		}
-		if(from == 0) {
-			knh_write_TAB(ctx, w);
-			knh_write_sname(ctx, w, cid);
-			knh_write_EOL(ctx, w);
-			from = 1;
-		}
-		knh_Translator_t *mpr = tmaps->trans[i];
-		knh_write_TAB(ctx, w); knh_write_TAB(ctx, w);
-		if(knh_Translator_isTotal(mpr)) {
-			knh_write_text(ctx, w, "==> ");
-		}
-		else {
-			knh_write_text(ctx, w, "--> ");
-		}
-		knh_write_sname(ctx, w, SP(mpr)->tcid);
-		knh_write_EOL(ctx, w);
-	}
-	if(ClassTBL(cid).supcid != CLASS_Object) {
-		cid = ClassTBL(cid).supcid;
-		tmaps = ClassTBL(cid).tmaps;
-		from = 0;
-		goto L_TAIL;
-	}
-}
+///* ======================================================================== */
+///* [man] */
+//
+//static char *knh_methodop__tochar(knh_methodn_t mn)
+//{
+//	switch(mn) {
+//	case MN_opNOT: return "!x";
+//	case MN_opOF: return "x instanceof T";
+//
+//	case MN_opHAS:  return "y in x";
+//	case MN_opIS:  return "x is y";
+////	case MN_opAs:  return "x as y";
+////	case MN_opInto:  return "x into y";
+//
+//	case MN_opEQ:  return "x == y";
+//	case MN_opNOTEQ:  return "x != y";
+//	case MN_opLT:  return "x < y";
+//	case MN_opLTE:  return "x <= y";
+//	case MN_opGT:  return "x > y";
+//	case MN_opGTE:  return "x >= y";
+//
+//	case MN_opLSFT:  return "x << y";
+//	case MN_opSEND:  return "x << y";
+//	case MN_opRSFT:  return "x >> y";
+//
+//	case MN_opMOD:  return "x mod y";
+//
+//	case MN_opADD:  return "x + y";
+//	case MN_opNEG:  return "-x";
+//	case MN_opSUB:  return "x - y";
+//	case MN_opDIV:  return "x / y";
+//	case MN_opMUL:  return "x * y";
+//
+//	case MN_opLOR:        return "x & y";
+//	case MN_opLAND:       return "x | y";
+//	case MN_opLNOT:       return "~x";
+//	case MN_opLXOR:        return "x ^ y";
+//	case MN_opNEXT:       return "x++";
+//	case MN_opPREV:       return "x--";
+//	case MN_opITR:        return "x..";
+//	case MN_getSize:      return "|x|";
+//	case MN_get:          return "x[n]";
+//	case MN_set:          return "x[n]=y";
+//	case MN_setAll:       return "x[]=y";
+//	case MN_opTO:    return "x[m to n]";
+//	case MN_opUNTIL: return "x[m until n]";
+//	case MN_opEXPAND:          return "a,b = x";
+//	}
+//	return NULL;
+//}
+//
+//static void knh_ClassNAME__man(Ctx *ctx, knh_class_t cid, knh_OutputStream_t *w)
+//{
+//	knh_write(ctx, w, STEXT("Class"));
+//	knh_write_EOL(ctx, w);
+//
+//	knh_write_TAB(ctx, w);
+//	knh_write_ltype(ctx, w, cid);
+//	knh_write_EOL(ctx, w);
+//
+//	while(ClassTBL(cid).supcid != CLASS_Object) {
+//		cid = ClassTBL(cid).supcid;
+//		knh_write_TAB(ctx, w);
+//		knh_write(ctx, w, STEXT("extends "));
+//		knh_write_ltype(ctx, w, cid);
+//		knh_write_EOL(ctx, w);
+//	}
+//}
+//
+//static void knh_ClassCONST__man(Ctx *ctx, knh_class_t cid, knh_OutputStream_t *w)
+//{
+//	DBG_ASSERT_cid(cid);
+//	if(ClassTBL(cid).constDictMap == NULL) return ;
+//	knh_DictMap_t *tcmap = ClassTBL(cid).constDictMap;
+//	size_t i, size = knh_DictMap_size(tcmap);
+//	OLD_LOCK(ctx, LOCK_SYSTBL, NULL);
+//	int hasCaption = 0;
+//	for(i = 0; i < size; i++) {
+//		if(!hasCaption) {
+//			knh_write_char(ctx, w, _("Const"));
+//			knh_write_EOL(ctx, w);
+//			hasCaption = 1;
+//		}
+//		knh_printf(ctx, w, "\t%s.%s: %O\n", CLASS__(cid),
+//				S_tochar(knh_DictMap_keyAt(tcmap, i)),
+//				knh_DictMap_valueAt(tcmap, i));
+//	}
+//	OLD_UNLOCK(ctx, LOCK_SYSTBL, NULL);
+//}
+//
+//
+//static void knh_Method__man(Ctx *ctx, knh_Method_t *o, knh_OutputStream_t *w, knh_class_t cid)
+//{
+//	if(!knh_Context_isVerbose(ctx)) {
+//		if(knh_Method_isPrivate(o)) return;
+//	}
+//
+//	if(knh_Method_isAbstract(o)) {
+//		knh_write(ctx, w, STEXT("@Abstract"));
+//		knh_putc(ctx, w, ' ');
+//	}
+//
+//	knh_write_type(ctx, w, knh_type_tocid(ctx, knh_ParamArray_rtype(DP(o)->mp), cid));
+//	knh_putc(ctx, w, ' ');
+//
+//	if(knh_Method_isStatic(o)) {
+//		knh_write_char(ctx, w, CTXCLASS__(cid));
+//		knh_putc(ctx, w, '.');
+//	}
+//	knh_write_mn(ctx, w, DP(o)->mn);
+//
+//	knh_putc(ctx, w, '(');
+//	size_t i;
+//	for(i = 0; i < knh_Method_psize(o); i++) {
+//		knh_param_t *p = knh_ParamArray_get(DP(o)->mp, i);
+//		if(i > 0) {
+//			knh_write_delim(ctx, w);
+//		}
+//		knh_write_type(ctx, w, knh_type_tocid(ctx, p->type, cid));
+//		knh_putc(ctx, w, ' ');
+//		knh_write(ctx, w, B(FN__(p->fn)));
+//	}
+//	if(knh_ParamArray_isVARGs(DP(o)->mp)) {
+//		knh_write_delim(ctx, w);
+//		knh_write_dots(ctx, w);
+//	}
+//	knh_putc(ctx, w, ')');
+//}
+//
+//static void knh_ClassMap__man(Ctx *ctx, knh_Array_t *tmaps, knh_OutputStream_t *w, knh_class_t cid)
+//{
+//	size_t i;
+//	int hasCaption = 0, from = 0;
+//	L_TAIL:;
+//	for(i = 0; i < tmaps->size; i++) {
+//		if(hasCaption == 0) {
+//			knh_write_char(ctx, w, _("Translator"));
+//			knh_write_EOL(ctx, w);
+//			hasCaption = 1;
+//		}
+//		if(from == 0) {
+//			knh_write_TAB(ctx, w);
+//			knh_write_sname(ctx, w, cid);
+//			knh_write_EOL(ctx, w);
+//			from = 1;
+//		}
+//		knh_Translator_t *mpr = tmaps->trans[i];
+//		knh_write_TAB(ctx, w); knh_write_TAB(ctx, w);
+//		if(knh_Translator_isTotal(mpr)) {
+//			knh_write_char(ctx, w, "==> ");
+//		}
+//		else {
+//			knh_write_char(ctx, w, "--> ");
+//		}
+//		knh_write_sname(ctx, w, SP(mpr)->tcid);
+//		knh_write_EOL(ctx, w);
+//	}
+//	if(ClassTBL(cid).supcid != CLASS_Object) {
+//		cid = ClassTBL(cid).supcid;
+//		tmaps = ClassTBL(cid).tmaps;
+//		from = 0;
+//		goto L_TAIL;
+//	}
+//}
 
 /* ------------------------------------------------------------------------ */
 //## method void Class.%man();
@@ -1064,138 +1029,139 @@ static void knh_ClassMap__man(Ctx *ctx, knh_Array_t *tmaps, knh_OutputStream_t *
 
 static METHOD Class__man(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	//KNH_TODO("man Class");
-	knh_class_t cid, this_cid;
-	knh_OutputStream_t *w = WWW;
-	size_t i = 0;
-	knh_DictMap_t *dm = new_DictMap0(ctx, 128);
-	BEGIN_LOCAL(ctx, lsfp, 1);
-	KNH_SETv(ctx, lsfp[0].o, dm);
-
-	if(IS_Class(sfp[1].o)) {
-		this_cid = ((knh_Class_t*)sfp[1].o)->cid;
-		DBG_ASSERT_cid(this_cid);
-	}
-	else {
-		this_cid = knh_Object_cid(sfp[1].o);
-	}
-	cid = this_cid;
-	while(1) {
-		knh_cwb_t cwbbuf, *cwb = knh_cwb_open(ctx, &cwbbuf);
-		knh_Array_t *a = ClassTBL(cid).methods;
-		for(i = 0; i < knh_Array_size(a); i++) {
-			knh_Method_t *mtd = (knh_Method_t*)knh_Array_n(a, i);
-			const char *op = knh_methodop__tochar(DP(mtd)->mn);
-			if(op == NULL) {
-				knh_cwb_clear(cwb, 0);
-				knh_write_mn(ctx, cwb->w, DP(mtd)->mn);
-				if(knh_DictMap_getNULL(ctx, dm, knh_cwb_tobytes(cwb)) == NULL) {
-					knh_DictMap_set(ctx, dm, knh_cwb_newString(ctx, cwb), mtd);
-				}
-			}
-			else {
-				if(knh_DictMap_getNULL(ctx,  dm, B(op)) == NULL) {
-					knh_DictMap_set(ctx, dm, new_T(op), mtd);
-				}
-			}
-		}
-		if(cid == CLASS_Object) {
-			knh_cwb_close(cwb);
-			break;
-		}
-		cid = ClassTBL(cid).supcid;
-	}
-
-	knh_ClassNAME__man(ctx, this_cid, w);
-	knh_ClassCONST__man(ctx, this_cid, w);
-
-	int cnt = 0;
-	int hasCaption = 0;
-	int isBOL = 1;
-	char buf[40];
-	for(i = 0; i < knh_DictMap_size(dm); i++) {
-		knh_Method_t *mtd = (knh_Method_t*)knh_DictMap_valueAt(dm, i);
-		if(IS_Method(mtd)) {
-			const char *op = knh_methodop__tochar(DP(mtd)->mn);
-			if(op == NULL) continue;
-			knh_DictMap_removeAt(ctx, dm, i);
-			if(DP(mtd)->cid == CLASS_Object && this_cid != CLASS_Object) continue;
-			if(hasCaption == 0) {
-				knh_write_text(ctx, w, _("Operator"));
-				knh_write_EOL(ctx, w);
-				hasCaption = 1;
-			}
-			if(isBOL == 1) {
-				knh_write_TAB(ctx, w);
-				isBOL = 0;
-			}
-			knh_snprintf(buf, sizeof(buf), "%10s  ", op);
-			knh_write_text(ctx, w, buf);
-			if(cnt % 5 == 4) {
-				knh_write_EOL(ctx, w);
-				isBOL = 1;
-			}
-			cnt++;
-		}
-	}
-	if(isBOL != 1) {
-		knh_write_EOL(ctx, w);
-	}
-
-	hasCaption = 0;
-	isBOL = 1;
-	//knh_DictMap_sort(dm);
-
-	for(i = 0; i < knh_DictMap_size(dm); i++) {
-		knh_Method_t *mtd = (knh_Method_t*)knh_DictMap_valueAt(dm, i);
-		if(IS_Method(mtd)) {
-			if(MN_isFMT(DP(mtd)->mn)) continue;
-			if(DP(mtd)->cid == CLASS_Object && this_cid != CLASS_Object) continue;
-			if(hasCaption == 0) {
-				knh_write_text(ctx, w, _("Method"));
-				knh_write_EOL(ctx, w);
-				hasCaption = 1;
-			}
-#if defined(K_USING_DEBUG)
-			if(1)
-#else
-			if(!knh_Method_isPrivate(mtd) || !knh_Method_isHidden(mtd))
-#endif
-			{
-				knh_write_TAB(ctx, w);
-				knh_Method__man(ctx, mtd, w, this_cid);
-				knh_write_EOL(ctx, w);
-			}
-			//knh_DictMap_removeAt(ctx, dm, i);
-		}
-	}
-
-	hasCaption = 0;
-	cnt = 8;
-	for(i = 0; i < knh_DictMap_size(dm); i++) {
-		knh_Method_t *mtd = (knh_Method_t*)knh_DictMap_valueAt(dm, i);
-		if(IS_Method(mtd)) {
-			if(!MN_isFMT(DP(mtd)->mn)) continue;
-			if(DP(mtd)->cid == CLASS_Object && this_cid != CLASS_Object) continue;
-			if(hasCaption == 0) {
-				knh_write_text(ctx, w, _("Formatter"));
-				knh_write_EOL(ctx, w);
-				knh_write_TAB(ctx, w);
-				hasCaption = 1;
-			}
-			knh_bytes_t k = S_tobytes(knh_DictMap_keyAt(dm, i));
-			if(cnt + k.len > 72) {
-				knh_write_EOL(ctx, w);
-				knh_write_TAB(ctx, w);
-				cnt = 8;
-			}
-			knh_write(ctx, w, k); knh_putc(ctx, w, ' ');
-			cnt += (k.len + 1);
-		}
-	}
-	knh_write_EOL(ctx, w);
-	knh_ClassMap__man(ctx, ClassTBL(this_cid).tmaps, w, this_cid);
-	END_LOCAL(ctx, lsfp);
+	KNH_TODO("man Class");
+//	knh_class_t cid, this_cid;
+//	knh_OutputStream_t *w = WWW;
+//	size_t i = 0;
+//	knh_DictMap_t *dm = new_DictMap0(ctx, 128);
+//	BEGIN_LOCAL(ctx, lsfp, 1);
+//	KNH_SETv(ctx, lsfp[1].o, dm);
+//
+//	if(IS_Class(sfp[1].o)) {
+//		this_cid = ((knh_Class_t*)sfp[1].o)->cid;
+//		DBG_ASSERT_cid(this_cid);
+//	}
+//	else {
+//		this_cid = knh_Object_cid(sfp[1].o);
+//	}
+//	cid = this_cid;
+//	while(1) {
+//		knh_cwb_t cwbbuf, *cwb = knh_cwb_open(ctx, &cwbbuf);
+//		knh_Array_t *a = ClassTBL(cid).methods;
+//		for(i = 0; i < knh_Array_size(a); i++) {
+//			knh_Method_t *mtd = (knh_Method_t*)knh_Array_n(a, i);
+//			char *op = knh_methodop__tochar(DP(mtd)->mn);
+//			if(op == NULL) {
+//				knh_cwb_clear(cwb, 0);
+//				knh_write_mn(ctx, cwb->w, DP(mtd)->mn);
+//				if(knh_DictMap_getNULL(ctx, dm, knh_cwb_tobytes(cwb)) == NULL) {
+//					knh_DictMap_set(ctx, dm, knh_cwb_newString(ctx, cwb), mtd);
+//				}
+//			}
+//			else {
+//				knh_bytes_t name = B(op);
+//				if(knh_DictMap_getNULL(ctx,  dm, name) == NULL) {
+//					knh_DictMap_set(ctx, dm, new_T(op), mtd);
+//				}
+//			}
+//		}
+//		if(cid == CLASS_Object) {
+//			knh_cwb_close(cwb);
+//			break;
+//		}
+//		cid = ClassTBL(cid).supcid;
+//		END_LOCAL(ctx, lsfp);
+//	}
+//
+//	knh_ClassNAME__man(ctx, this_cid, w);
+//	knh_ClassCONST__man(ctx, this_cid, w);
+//
+//	int cnt = 0;
+//	int hasCaption = 0;
+//	int isBOL = 1;
+//	char buf[40];
+//	for(i = 0; i < knh_DictMap_size(dm); i++) {
+//		knh_Method_t *mtd = (knh_Method_t*)knh_DictMap_valueAt(dm, i);
+//		if(IS_Method(mtd)) {
+//			char *op = knh_methodop__tochar(DP(mtd)->mn);
+//			if(op == NULL) continue;
+//			knh_DictMap_removeAt(ctx, dm, i);
+//			if(DP(mtd)->cid == CLASS_Object && this_cid != CLASS_Object) continue;
+//			if(hasCaption == 0) {
+//				knh_write_char(ctx, w, _("Operator"));
+//				knh_write_EOL(ctx, w);
+//				hasCaption = 1;
+//			}
+//			if(isBOL == 1) {
+//				knh_write_TAB(ctx, w);
+//				isBOL = 0;
+//			}
+//			knh_snprintf(buf, sizeof(buf), "%10s  ", op);
+//			knh_write_char(ctx, w, buf);
+//			if(cnt % 5 == 4) {
+//				knh_write_EOL(ctx, w);
+//				isBOL = 1;
+//			}
+//			cnt++;
+//		}
+//	}
+//	if(isBOL != 1) {
+//		knh_write_EOL(ctx, w);
+//	}
+//
+//	hasCaption = 0;
+//	isBOL = 1;
+//	knh_DictMap_sort(dm);
+//
+//	for(i = 0; i < knh_DictMap_size(dm); i++) {
+//		knh_Method_t *mtd = (knh_Method_t*)knh_DictMap_valueAt(dm, i);
+//		if(IS_Method(mtd)) {
+//			if(MN_isFMT(DP(mtd)->mn)) continue;
+//			if(DP(mtd)->cid == CLASS_Object && this_cid != CLASS_Object) continue;
+//			if(hasCaption == 0) {
+//				knh_write_char(ctx, w, _("Method"));
+//				knh_write_EOL(ctx, w);
+//				hasCaption = 1;
+//			}
+//#if defined(K_USING_DEBUG)
+//			if(1)
+//#else
+//			if(!knh_Method_isPrivate(mtd) || !knh_Method_isHidden(mtd))
+//#endif
+//			{
+//				knh_write_TAB(ctx, w);
+//				knh_Method__man(ctx, mtd, w, this_cid);
+//				knh_write_EOL(ctx, w);
+//			}
+//			//knh_DictMap_removeAt(ctx, dm, i);
+//		}
+//	}
+//
+//	hasCaption = 0;
+//	cnt = 8;
+//	for(i = 0; i < knh_DictMap_size(dm); i++) {
+//		knh_Method_t *mtd = (knh_Method_t*)knh_DictMap_valueAt(dm, i);
+//		if(IS_Method(mtd)) {
+//			if(!MN_isFMT(DP(mtd)->mn)) continue;
+//			if(DP(mtd)->cid == CLASS_Object && this_cid != CLASS_Object) continue;
+//			if(hasCaption == 0) {
+//				knh_write_char(ctx, w, _("Formatter"));
+//				knh_write_EOL(ctx, w);
+//				knh_write_TAB(ctx, w);
+//				hasCaption = 1;
+//			}
+//			knh_bytes_t k = S_tobytes(knh_DictMap_keyAt(dm, i));
+//			if(cnt + k.len > 72) {
+//				knh_write_EOL(ctx, w);
+//				knh_write_TAB(ctx, w);
+//				cnt = 8;
+//			}
+//			knh_write(ctx, w, k); knh_putc(ctx, w, ' ');
+//			cnt += (k.len + 1);
+//		}
+//	}
+//	knh_write_EOL(ctx, w);
+//	knh_ClassMap__man(ctx, ClassTBL(this_cid).tmaps, w, this_cid);
 }
 
 /* ------------------------------------------------------------------------ */
