@@ -73,51 +73,38 @@ static TCAST Int_Float(Ctx *ctx, knh_sfp_t *sfp, long rix)
 	RETURNf_(v);
 }
 
-/* ------------------------------------------------------------------------ */
-//## @Const @Final mapper String Float;
-
-static TCAST String_Float(Ctx *ctx, knh_sfp_t *sfp, long rix)
-{
-	knh_float_t v = 0.0;
-	if(!knh_bytes_parsefloat(S_tobytes(sfp[K_TRLIDX].s), &v)) {
-		KNH_SETv(ctx, sfp[rix].o, KNH_NULVAL(CLASS_Float));
-	}
-	RETURNf_(v);
-}
-
-
 /* ======================================================================== */
 /* [toString] */
 
-/* ------------------------------------------------------------------------ */
-//## @Const @Final @LossLess mapper Boolean String;
-
-static TCAST Boolean_String(Ctx *ctx, knh_sfp_t *sfp, long rix)
-{
-	knh_String_t *s = (Boolean_to(int, (sfp[K_TRLIDX]))) ? TS_true : TS_false;
-	RETURN_(s);
-}
-
-/* ------------------------------------------------------------------------ */
-//## @Const @Final @LossLess mapper Int String;
-
-static TCAST Int_String(Ctx *ctx, knh_sfp_t *sfp, long rix)
-{
-	char buf[256];
-	knh_snprintf(buf, sizeof(buf), K_INT_FMT, sfp[K_TRLIDX].ivalue);
-	RETURN_(new_S(ctx, B(buf)));
-}
-
-/* ------------------------------------------------------------------------ */
-//## @Const @Final @LossLess mapper Float String;
-
-static TCAST Float_String(Ctx *ctx, knh_sfp_t *sfp, long rix)
-{
-	char buf[256];
-	knh_snprintf(buf, sizeof(buf), K_FLOAT_FMT, sfp[K_TRLIDX].fvalue);
-	RETURN_(new_S(ctx, B(buf)));
-}
-
+///* ------------------------------------------------------------------------ */
+////## @Const @Final @LossLess mapper Boolean String;
+//
+//static TCAST Boolean_String(Ctx *ctx, knh_sfp_t *sfp, long rix)
+//{
+//	knh_String_t *s = (p_bool(sfp[K_TRLIDX])) ? TS_true : TS_false;
+//	RETURN_(s);
+//}
+//
+///* ------------------------------------------------------------------------ */
+////## @Const @Final @LossLess mapper Int String;
+//
+//static TCAST Int_String(Ctx *ctx, knh_sfp_t *sfp, long rix)
+//{
+//	char buf[256];
+//	knh_snprintf(buf, sizeof(buf), K_INT_FMT, sfp[K_TRLIDX].ivalue);
+//	RETURN_(new_S(ctx, B(buf)));
+//}
+//
+///* ------------------------------------------------------------------------ */
+////## @Const @Final @LossLess mapper Float String;
+//
+//static TCAST Float_String(Ctx *ctx, knh_sfp_t *sfp, long rix)
+//{
+//	char buf[256];
+//	knh_snprintf(buf, sizeof(buf), K_FLOAT_FMT, sfp[K_TRLIDX].fvalue);
+//	RETURN_(new_S(ctx, B(buf)));
+//}
+//
 ///* ------------------------------------------------------------------------ */
 ////## @Const @Final mapper Bytes String;
 //
@@ -134,15 +121,15 @@ static TCAST Float_String(Ctx *ctx, knh_sfp_t *sfp, long rix)
 /* ======================================================================== */
 /* [toBytes] */
 
-/* ------------------------------------------------------------------------ */
-//## @Const @Final mapper String Bytes;
-
-static TCAST String_Bytes(Ctx *ctx, knh_sfp_t *sfp, long rix)
-{
-	knh_Bytes_t *b = new_Bytes(ctx, S_size(sfp[K_TRLIDX].s) + 1);
-	knh_Bytes_write(ctx, b, S_tobytes(sfp[K_TRLIDX].s));
-	RETURN_(b);
-}
+///* ------------------------------------------------------------------------ */
+////## @Const @Final mapper String Bytes;
+//
+//static TCAST String_Bytes(Ctx *ctx, knh_sfp_t *sfp, long rix)
+//{
+//	knh_Bytes_t *b = new_Bytes(ctx, S_size(sfp[K_TRLIDX].s) + 1);
+//	knh_Bytes_write(ctx, b, S_tobytes(sfp[K_TRLIDX].s));
+//	RETURN_(b);
+//}
 
 /* ======================================================================== */
 /* [Iterator] */
@@ -160,13 +147,13 @@ static TCAST Object_Iterator(Ctx *ctx, knh_sfp_t *sfp, long rix)
 /* ======================================================================== */
 /* [Iterator] */
 
-void knh_stack_boxing(Ctx *ctx, knh_sfp_t *sfp)
-{
-	knh_class_t bcid = (sfp[0].o)->h.bcid;
-	if(CLASS_Boolean <= bcid && bcid <= CLASS_Float && sfp[0].data != knh_Object_data(sfp[0].o)) {
-		klr_mov(ctx, sfp[0].o, new_Object_boxing(ctx, knh_Object_cid(sfp[0].o), sfp));
-	}
-}
+//void knh_stack_boxing(Ctx *ctx, knh_sfp_t *sfp)
+//{
+//	knh_class_t bcid = (sfp[0].o)->h.bcid;
+//	if(CLASS_Boolean <= bcid && bcid <= CLASS_Float && sfp[0].data != knh_Object_data(sfp[0].o)) {
+//		klr_mov(ctx, sfp[0].o, new_Object_boxing(ctx, knh_Object_cid(sfp[0].o), sfp));
+//	}
+//}
 
 /* ------------------------------------------------------------------------ */
 //## mapper Iterator Array!;
