@@ -117,7 +117,7 @@ static METHOD Object_new__MAP(Ctx *ctx, knh_sfp_t *sfp, long rix)
 static METHOD Bytes_new(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
 	knh_Bytes_t *ba = sfp[0].ba;
-	size_t init = sfp[1].ivalue <= 0 ? 4 : knh_good_size(Int_to(size_t, sfp[1]));
+	size_t init = sfp[1].ivalue <= 0 ? 0 : knh_good_size(Int_to(size_t, sfp[1]));
 	DBG_ASSERT(ba->capacity == 0);
 	ba->bu.ubuf = (knh_uchar_t*)KNH_MALLOC(ctx, init);
 	knh_bzero(ba->bu.ubuf, init);
@@ -163,8 +163,7 @@ static METHOD Regex_new(Ctx *ctx, knh_sfp_t *sfp, long rix)
 	const char *ptn = ctx->api->tochar(ctx, sfp[1].s);
 	const char *opt = IS_NULL(sfp[2].o) ? "" : ctx->api->tochar(ctx, sfp[2].s);
 	KNH_SETv(ctx, re->pattern, sfp[1].s);
-	knh_NameSpace_t *ns = IS_NULL(sfp[3].ns)?knh_getGammaNameSpace(ctx):sfp[3].ns;
-	re->spi = DP(ns)->regexSPI;
+	re->spi = DP(sfp[2].ns)->regexSPI;
 	re->reg = re->spi->regmalloc(ctx, sfp[1].s);
 	re->spi->regcomp(ctx, re->reg, ptn, re->spi->parse_cflags(ctx, opt));
 	re->eflags = re->spi->parse_eflags(ctx, opt);
@@ -294,14 +293,14 @@ static METHOD Array_new__LIST(Ctx *ctx, knh_sfp_t *sfp, long rix)
 
 static METHOD Map_new(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	knh_Map_t *m = (knh_Map_t *)sfp[0].o;
-	size_t init = sfp[1].ivalue <= 0 ? 0: Int_to(size_t, sfp[1]);
-	knh_bytes_t path = S_tobytes(sfp[2].s);
-	knh_class_t cid = knh_Object_cid(m);
-	knh_MapDSPI_t *dspi = knh_getMapDSPI(ctx, path);
-	m->dspi = dspi->config(ctx, knh_class_p1(cid), knh_class_p2(cid));
-	m->map = m->dspi->init(ctx, init, path.text, NULL);
-	RETURN_(m);
+	KNH_TODO(__FUNCTION__);
+//	knh_DictMap_t *o = (knh_DictMap_t*)sfp[0].o;
+//	size_t init = sfp[1].ivalue <= 0 ? 0: Int_to(size_t, sfp[1]);
+//	if(init > knh_dict_capacity(o->_list)) {
+//		o->_list = knh_dict_resize(ctx, o->_list, init);
+//		o->size = 0;
+//	}
+//	RETURN_(o);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -309,23 +308,18 @@ static METHOD Map_new(Ctx *ctx, knh_sfp_t *sfp, long rix)
 
 static METHOD Map_new__MAP(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	knh_Map_t *o = (knh_Map_t*)sfp[0].o;
-	knh_class_t cid = knh_Object_cid(o);
-	knh_sfp_t *v = sfp + 1;
-	size_t i, ac = knh_stack_argc(ctx, v);
-	knh_class_t p1 = knh_class_p1(cid);
-	knh_class_t p2 = knh_class_p2(cid);
-	knh_MapDSPI_t *dspi = knh_getMapDSPIfromCID(ctx, p1, p2);
-	o->dspi = dspi->config(ctx, p1, p2);
-	o->map  = dspi->init(ctx, 0, dspi->name, NULL);
-
-	for(i = 0; i < ac; i+=2) {
-		if(IS_bString(v[i].s)) {
-			knh_stack_boxing(ctx, v + i + 1);
-			o->dspi->set(ctx, o->map, v+i);
-		}
-	}
-	RETURN_(o);
+	KNH_TODO(__FUNCTION__);
+//	knh_DictMap_t *o = (knh_DictMap_t*)sfp[0].o;
+//	knh_sfp_t *v = sfp + 1;
+//	size_t i, ac = knh_stack_argc(ctx, v);
+//	for(i = 0; i < ac; i+=2) {
+//		if(IS_bString(v[i].s)) {
+//			knh_stack_boxing(ctx, v + i + 1);
+//			knh_DictMap_append(ctx, o, v[i].s, v[i+1].o);
+//		}
+//	}
+//	knh_DictMap_sort(o);
+//	RETURN_(o);
 }
 
 /* ------------------------------------------------------------------------ */
