@@ -468,11 +468,11 @@ static METHOD String_opSUB(Ctx *ctx, knh_sfp_t *sfp, long rix)
 
 static METHOD Any_opADD(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	knh_Method_t *mtd = sfp[K_MTDIDX].mtdNC;
+	knh_Method_t *mtd = sfp[K_MTDIDX].callmtd;
 	mtd = knh_lookupMethod(ctx, knh_Object_cid(sfp[0].o), DP(mtd)->mn);
-	klr_setmtdNC(ctx, sfp[K_MTDIDX], mtd);
+	klr_setcallmtd(ctx, sfp[K_MTDIDX], mtd);
 	knh_stack_typecheck(ctx, sfp, mtd, NULL);
-	(sfp[K_MTDIDX].mtdNC)->fcall_1(ctx, sfp, rix);
+	(sfp[K_MTDIDX].callmtd)->fcall_1(ctx, sfp, rix);
 }
 
 /* ======================================================================== */
@@ -553,7 +553,6 @@ static METHOD Int_opRSFT(Ctx *ctx, knh_sfp_t *sfp, long rix)
 
 METHOD Bytes_getSize(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	//fprintf(stderr, "** rix=%ld sfp[rix]=%p\n", rix, sfp + rix);
 	RETURNi_((sfp[0].ba)->bu.len);
 }
 
