@@ -123,25 +123,25 @@ static METHOD String_endsWith(Ctx *ctx, knh_sfp_t *sfp, long rix)
 	RETURNb_(knh_bytes_endsWith(S_tobytes(sfp[0].s), S_tobytes(sfp[1].s)));
 }
 
-/* ------------------------------------------------------------------------ */
-//## @Const method String String.concat(Object value, ...);
-//## @Const method String String.opADD(Any value);
-
-static METHOD String_concat(Ctx *ctx, knh_sfp_t *sfp, long rix)
-{
-	int i, ac = knh_stack_argc(ctx, sfp);
-	knh_cwb_t cwbbuf, *cwb = knh_cwb_open(ctx, &cwbbuf);
-	knh_Method_t *mtd = knh_findFormatter(ctx, CLASS_Object, MN__s);
-	for(i = 0; i < ac; i++) {
-		if(IS_bString(sfp[i].o)) {
-			knh_Bytes_write(ctx, cwb->ba, S_tobytes(sfp[i].s));
-		}
-		else if(!knh_write_ndata(ctx, cwb->w, knh_Object_bcid(sfp[i].o), sfp[i].data)) {
-			knh_write_Object(ctx, cwb->w, sfp+ac, &mtd, sfp[i].o);
-		}
-	}
-	RETURN_(knh_cwb_newString(ctx, cwb));
-}
+///* ------------------------------------------------------------------------ */
+////## @Const method String String.concat(Object value, ...);
+////## @Const method String String.opADD(Any value);
+//
+//static METHOD String_concat(Ctx *ctx, knh_sfp_t *sfp, long rix)
+//{
+//	int i, ac = knh_stack_argc(ctx, sfp);
+//	knh_cwb_t cwbbuf, *cwb = knh_cwb_open(ctx, &cwbbuf);
+//	knh_Method_t *mtd = knh_getDefaultFormatter(ctx, MN__s);
+//	for(i = 0; i < ac; i++) {
+//		if(IS_bString(sfp[i].o)) {
+//			knh_Bytes_write(ctx, cwb->ba, S_tobytes(sfp[i].s));
+//		}
+//		else if(!knh_write_ndata(ctx, cwb->w, knh_Object_bcid(sfp[i].o), sfp[i].data)) {
+//			knh_write_Object(ctx, cwb->w, sfp+ac, &mtd, sfp[i].o);
+//		}
+//	}
+//	RETURN_(knh_cwb_newString(ctx, cwb));
+//}
 
 /* ------------------------------------------------------------------------ */
 //## @Const method Int String.indexOf(String s);
@@ -149,10 +149,8 @@ static METHOD String_concat(Ctx *ctx, knh_sfp_t *sfp, long rix)
 static METHOD String_indexOf(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
 	knh_bytes_t base = S_tobytes(sfp[0].s);
-	if (IS_NULL(sfp[1].o)) RETURNi_(-1);
 	knh_bytes_t delim = S_tobytes(sfp[1].s);
 	knh_index_t loc = knh_bytes_indexOf(base, delim);
-	if(delim.len == 0) loc--;
 	if (loc >= 0 && !knh_String_isASCII(sfp[0].s)) {
 		base.len = (size_t)loc;
 		loc = knh_bytes_mlen(base);
@@ -166,7 +164,6 @@ static METHOD String_indexOf(Ctx *ctx, knh_sfp_t *sfp, long rix)
 static METHOD String_lastIndexOf(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
 	knh_bytes_t base = S_tobytes(sfp[0].s);
-	if (IS_NULL(sfp[1].o)) RETURNi_(-1);
 	knh_bytes_t delim = S_tobytes(sfp[1].s);
 	knh_index_t loc = base.len - delim.len;
 	if(delim.len == 0) loc--;
@@ -189,11 +186,10 @@ static METHOD String_lastIndexOf(Ctx *ctx, knh_sfp_t *sfp, long rix)
 static METHOD String_search(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
 	knh_Regex_t *re = sfp[1].re;
-	if(IS_NULL(re) || S_size(re->pattern) == 0) RETURNi_(-1);
 	knh_index_t loc = -1;
 	const char *str = ctx->api->tochar(ctx, sfp[0].s);  // necessary
-	knh_regmatch_t pmatch[1];
-	int res = re->spi->regexec(ctx, re->reg, str, 1, pmatch, re->eflags);
+	knh_regmatch_t pmatch[K_REGEX_MATCHSIZE];
+	int res = re->spi->regexec(ctx, re->reg, str, K_REGEX_MATCHSIZE, pmatch, re->eflags);
 	if(res == 0) {
 		loc = pmatch[0].rm_so;
 		if (!knh_String_isASCII(sfp[0].s) && loc != -1) {
@@ -216,32 +212,26 @@ static METHOD String_match(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
 	knh_String_t *s0 = sfp[0].s;
 	knh_Regex_t *re = sfp[1].re;
-	knh_Array_t *a = NULL;
-	if(IS_NULL(re) || S_size(re->pattern) == 0) {
-		a = new_Array(ctx, CLASS_String, 0);
-	}
-	else {
-		const char *str = ctx->api->tochar(ctx, sfp[0].s);  // necessary
-		knh_regmatch_t pmatch[K_REGEX_MATCHSIZE];
-		int res = re->spi->regexec(ctx, re->reg, str, K_REGEX_MATCHSIZE, pmatch, re->eflags);
-		a = new_Array(ctx, CLASS_String, K_REGEX_MATCHSIZE);
-		if(res == 0) {
-			knh_bytes_t sub = S_tobytes(s0);
-			int i;
-			for(i = 0; i < K_REGEX_MATCHSIZE; i++) {
-				if(pmatch[i].rm_so == -1) break;
-				//DBG_P("[%d], rm_so=%d, rm_eo=%d", i, pmatch[i].rm_so, pmatch[i].rm_eo);
-				sub.text = str + pmatch[i].rm_so;
-				sub.len = pmatch[i].rm_eo - pmatch[i].rm_so;
-				knh_Array_add(ctx, a, new_String_(ctx, CLASS_String, sub, s0));
-			}
+	const char *str = ctx->api->tochar(ctx, sfp[0].s);  // necessary
+	knh_regmatch_t pmatch[K_REGEX_MATCHSIZE];
+	int res = re->spi->regexec(ctx, re->reg, str, K_REGEX_MATCHSIZE, pmatch, re->eflags);
+	knh_Array_t *a = new_Array(ctx, CLASS_String, K_REGEX_MATCHSIZE);
+	if(res == 0) {
+		knh_bytes_t sub = S_tobytes(s0);
+		int i;
+		for(i = 0; i < K_REGEX_MATCHSIZE; i++) {
+			if(pmatch[i].rm_so == -1) break;
+			//DBG_P("[%d], rm_so=%d, rm_eo=%d", i, pmatch[i].rm_so, pmatch[i].rm_eo);
+			sub.text = str + pmatch[i].rm_so;
+			sub.len = pmatch[i].rm_eo - pmatch[i].rm_so;
+			knh_Array_add(ctx, a, new_String_(ctx, CLASS_String, sub, s0));
 		}
-//		else {
-//			char ebuf[K_ERRBUFSIZE];
-//			re->spi->regerror(res, re->reg, ebuf, K_ERRBUFSIZE);
-//			ctx->api->ebilog(ctx, re->spi->name, "regexec", LOG_WARNING, "errmsg='%s'", ebuf);
-//		}
 	}
+//	else {
+//		char ebuf[K_ERRBUFSIZE];
+//		re->spi->regerror(res, re->reg, ebuf, K_ERRBUFSIZE);
+//		ctx->api->ebilog(ctx, re->spi->name, "regexec", LOG_WARNING, "errmsg='%s'", ebuf);
+//	}
 	RETURN_(a);
 }
 
@@ -261,32 +251,39 @@ static METHOD String_match(Ctx *ctx, knh_sfp_t *sfp, long rix)
 
 static METHOD String_replace(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	knh_String_t *s0 = sfp[0].s;
-	knh_Regex_t *re = sfp[1].re;
-	knh_String_t *s = s0;
-	if(!IS_NULL(re) && S_size(re->pattern) > 0) {
-		knh_cwb_t cwbbuf, *cwb = knh_cwb_open(ctx, &cwbbuf);
-		knh_bytes_t tos = S_tobytes(sfp[2].s);
-		const char *str = ctx->api->tochar(ctx, s0);  // necessary
-		const char *estr = str + S_size(s0);
-		knh_regmatch_t pmatch[K_REGEX_MATCHSIZE];
-		while (str < estr) {
-			int res = re->spi->regexec(ctx, re->reg, str, K_REGEX_MATCHSIZE, pmatch, re->eflags);
-			if (res == 0) {
-				knh_bytes_t sub = {{str},  pmatch[0].rm_so};
-				knh_Bytes_write(ctx, cwb->ba, sub);
-				knh_Bytes_write(ctx, cwb->ba, tos);
-				str += (pmatch[0].rm_eo);
-			}
-			else {
-				knh_bytes_t sub = {{str}, knh_strlen(str)};
-				knh_Bytes_write(ctx, cwb->ba, sub);
-				break;
-			}
-		}
-		s = knh_cwb_newString(ctx, cwb);
-	}
-	RETURN_(s);
+	KNH_TODO("String.replace");
+//	if(knh_Regex_isSTRREGEX(sfp[1].re)) { /* @author nakata */
+//		knh_bytes_t base = S_tobytes(sfp[0].s);
+//		knh_bytes_t target = S_tobytes((sfp[1].re)->pattern);
+//		knh_bytes_t alt = S_tobytes(sfp[2].s);
+//		knh_cwb_t cwbbuf, *cwb = knh_cwb_open(ctx, &cwbbuf);
+//		int search_flag= 0, ch = target.ustr[0];
+//		size_t i;
+//		if (base.len == 0 || target.len == 0 || base.len < target.len) {
+//			RETURN_(sfp[0].o);
+//		}
+//		for(i = 0; i < base.len - target.len+1; i++) {
+//			if(base.ustr[i] == ch && knh_bytes_equals_(base, i, target)) {
+//				knh_Bytes_write(ctx, cwb->ba, alt);
+//				i += target.len - 1;
+//				search_flag = 1;
+//			}else {
+//				knh_Bytes_putc(ctx, cwb->ba, base.ustr[i]);
+//			}
+//		}
+//		if(search_flag == 0) {
+//			RETURN_(sfp[0].o);
+//		}
+//		else {
+//			knh_bytes_t leftover = {{base.text + i}, base.len - i};
+//			knh_Bytes_write(ctx, cwb->ba, leftover);
+//			RETURN_(knh_cwb_newString(ctx, cwb));
+//		}
+//	}
+//	else {
+//		//knh_Regex_t *re = sfp[1].re;
+//		KNH_TODO("function, assigned to HIRA!!");
+//	}
 }
 
 /* ------------------------------------------------------------------------ */
@@ -309,7 +306,7 @@ static knh_Array_t *knh_String_toCharArray(Ctx *ctx, knh_String_t *bs, int istri
 		knh_Array_t *a = new_Array(ctx, CLASS_String, n);
 		for(i = 0; i < n; i++) {
 			if(istrim && isspace(base.ustr[i])) continue;
-			knh_bytes_t sub = knh_bytes_mofflen(base, i, 1);
+			knh_bytes_t sub = knh_bytes_mofflen(base, n, 1);
 			knh_Array_add(ctx, a, new_String_(ctx, CLASS_String, sub, bs));
 		}
 		return a;
@@ -386,7 +383,7 @@ static METHOD String_encode(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
 	knh_cwb_t cwbbuf, *cwb = knh_cwb_open(ctx, &cwbbuf);
 	knh_Converter_t *c = sfp[1].conv;
-	//fprintf(stderr, "%s, c=%p, c->dspi=%p, c->dspi->enc=****\n", CLASS__(c->h.cid), c, c->dspi);
+	fprintf(stderr, "%s, c=%p, c->dspi=%p, c->dspi->enc=****\n", CLASS__(c->h.cid), c, c->dspi);
 	c->dspi->enc(ctx, c->conv, S_tobytes(sfp[0].s), cwb->ba);
 	knh_Bytes_t *ba = new_Bytes(ctx, knh_cwb_size(cwb));
 	knh_Bytes_write(ctx, ba, knh_cwb_tobytes(cwb));
@@ -439,10 +436,10 @@ static METHOD String_trim(Ctx *ctx, knh_sfp_t *sfp, long rix)
 static METHOD Regex_opHAS(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
 	knh_Regex_t *re = sfp[0].re;
-	knh_regmatch_t pmatch[1];
+	knh_regmatch_t pmatch[K_REGEX_MATCHSIZE];
 	const char *str = ctx->api->tochar(ctx, sfp[1].s);
-	int res = re->spi->regexec(ctx, re->reg, str, 1, pmatch, re->eflags);
-	RETURNb_(res == 0);
+	int res = re->spi->regexec(ctx, re->reg, str, K_REGEX_MATCHSIZE, pmatch, re->eflags);
+	RETURNb_(res);
 }
 
 #endif/*K_USING_DEFAULTAPI*/
