@@ -39,7 +39,6 @@
 #define USE_bytes_startsWith  1
 #define USE_bytes_endsWith    1
 #define USE_bytes_parseint    1
-#define USE_bytes_parsefloat  1
 //#define USE_bytes_subbytes    1
 
 #define USE_cwb_open      1
@@ -63,7 +62,7 @@
 #define USE_getTimeMilliSecond 1
 
 #include"commons.h"
-#include"../../../include/konoha07/konoha_code_.h"
+#include"../../../include/konoha/konoha_code_.h"
 
 /* ************************************************************************ */
 
@@ -546,11 +545,7 @@ static knh_ObjectSPI_t BytesSPI = {
 
 static void knh_Tuple_init(Ctx *ctx, Object *o)
 {
-	knh_Tuple_t *t = (knh_Tuple_t*)o;
-	knh_Tuple_setTriple(t, 1);
-	KNH_INITv(t->first, KNH_NULL);
-	KNH_INITv(t->second, KNH_NULL);
-	KNH_INITv(t->thirdNULL, KNH_NULL);
+	KNH_TODO("new tuple");
 }
 
 static void knh_Tuple_traverse(Ctx *ctx, Object *o, knh_Ftraverse ftr)
@@ -726,7 +721,7 @@ static void knh_Iterator_free(Ctx *ctx, Object *o)
 //
 //static TCAST Iterator_Iterator(Ctx *ctx, knh_sfp_t *sfp, long rix)
 //{
-//	knh_Translator_t *trl = sfp[K_TRLIDX].trlNC;
+//	knh_Translator_t *trl = sfp[K_TRLIDX].casttrl;
 //	RETURN_(new_Iterator(ctx, knh_class_p1(SP(trl)->tcid), sfp[K_TRLIDX].o, knh_Iterator_filterNext));
 //}
 //
@@ -759,59 +754,10 @@ static knh_ObjectSPI_t IteratorSPI = {
 /* --------------- */
 /* Map */
 
-static knh_MapDSPI_t* nullmap_config(Ctx *ctx, knh_class_t p1, knh_class_t p2);
-static knh_map_t *nullmap_init(Ctx *ctx, size_t init, const char *path, void *option)
-{
-	KNH_TODO("NullMap.init");
-	return NULL;
-}
-static void nullmap_ftr(Ctx *ctx, knh_map_t *m, knh_Ftraverse ftr)
-{
-}
-static void nullmap_free(Ctx *ctx, knh_map_t *m)
-{
-}
-static knh_bool_t nullmap_get(Ctx *ctx, knh_map_t* m, knh_sfp_t *ksfp, knh_sfp_t *rsfp)
-{
-	KNH_TODO("NullMap.get");
-	return 1;
-}
-static knh_map_t* nullmap_set(Ctx *ctx, knh_map_t* m, knh_sfp_t *ksfp)
-{
-	KNH_TODO("NullMap.set");
-	return NULL;
-}
-static void nullmap_remove(Ctx *ctx, knh_map_t* m, knh_sfp_t *ksfp)
-{
-	KNH_TODO("NullMap.remove");
-}
-
-static size_t nullmap_size(Ctx *ctx, knh_map_t* m)
-{
-	KNH_TODO("NullMap.size");
-	return 0;
-}
-static knh_bool_t nullmap_setIterator(Ctx *ctx, knh_map_t* m, knh_Iterator_t *it)
-{
-	KNH_TODO("NullMap.setIterator");
-	return 1;
-}
-
-static knh_MapDSPI_t NULLMap = {
-	K_DSPI_MAP, "nullmap",
-	nullmap_config, nullmap_init, nullmap_ftr, nullmap_free,
-	nullmap_get, nullmap_set, nullmap_remove, nullmap_size,
-	nullmap_setIterator,
-};
-static knh_MapDSPI_t* nullmap_config(Ctx *ctx, knh_class_t p1, knh_class_t p2)
-{
-	return &NULLMap;
-}
-
 static void knh_Map_init(Ctx *ctx, Object *o)
 {
 	knh_Map_t *m = (knh_Map_t*)o;
-	m->dspi = &NULLMap;
+	m->dspi = NULL;
 	m->map = NULL;
 }
 
@@ -1015,7 +961,7 @@ static knh_ObjectSPI_t TranslatorSPI = {
 
 static METHOD knh_Fmethod_funcRTYPE(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	knh_type_t rtype = knh_ParamArray_rtype(DP(sfp[K_MTDIDX].mtdNC)->mp);
+	knh_type_t rtype = knh_ParamArray_rtype(DP(sfp[K_MTDIDX].callmtd)->mp);
 	if(rtype != TYPE_void) {
 		if(IS_Tunbox(rtype)) {
 			RETURNi_(K_INT0);  // same results in Float, Boolean
@@ -1245,12 +1191,11 @@ static int knh_strregex_regexec(Ctx *ctx, knh_regex_t *reg, const char *str, siz
 		p[e].rm_name.len = 0;
 		e++;
 	}
-	if (e < nmatch) {
-		p[e].rm_so = -1;
-		p[e].rm_eo = -1;
-		p[e].rm_name.ubuf = NULL;
-		p[e].rm_name.len = 0;
-	}
+	DBG_ASSERT(e < nmatch);
+	p[e].rm_so = -1;
+	p[e].rm_eo = -1;
+	p[e].rm_name.ubuf = NULL;
+	p[e].rm_name.len = 0;
 	return (po) ? 0 : -1;
 }
 
@@ -2140,8 +2085,6 @@ knh_Term_t *knh_Stmt_done(Ctx *ctx, knh_Stmt_t *o)
 
 static void knh_Gamma_init(Ctx *ctx, Object *o)
 {
-	knh_Gamma_t *gma = (knh_Gamma_t *) o;
-	gma->uri = 0;
 	knh_intptr_t i;
 	knh_GammaEX_t *b = KNH_MALLOCBODY(ctx, Gamma);
 	knh_bzero(b, sizeof(knh_GammaEX_t));
