@@ -34,7 +34,7 @@
 #endif
 
 #define K_USING_LOADDATA
-#include"../../include/konoha07/konoha_grammar_.h"
+#include"../../include/konoha/konoha_grammar_.h"
 
 /* ************************************************************************ */
 
@@ -55,7 +55,7 @@ char *TT__(knh_term_t tt);
 
 /* ------------------------------------------------------------------------ */
 
-static volatile size_t ctxid_counter = 1;
+volatile static size_t ctxid_counter = 1;
 
 static void knh_Object_RCsweep(Ctx *ctx, Object *o)
 {
@@ -112,19 +112,6 @@ static void knh_CommonContext_init(Ctx *ctx, knh_Context_t *o)
 	KNH_INITv(o->err, DP(ctx->sys)->err);
 	KNH_INITv(o->e, KNH_NULL);
 	o->ctxlock = knh_mutex_malloc(ctx);
-	{
-		knh_uintptr_t i = 0, ch;
-		knh_uint_t t = knh_rand();
-		ch = t % 26;
-		o->trace[i] = 'A' + ch;
-		for(i = 1; i < 9; i++) {
-			t = t / 36;
-			if (t == 0) t = knh_rand();
-			ch = t % 36;
-			o->trace[i] = (ch < 10) ? '0' + ch : 'A' + (ch - 10);
-		}
-	}
-	o->seq = 0;
 }
 
 static void knh_CommonContext_traverse(Ctx *ctx, knh_Context_t *ctxo, knh_Ftraverse ftr)
@@ -167,26 +154,18 @@ static void knh_CommonContext_free(Ctx *ctx, knh_Context_t *ctxo)
 
 static void _vsyslog(int p, const char *fmt, va_list ap)
 {
-#ifdef K_USING_SYSLOG
-	vsyslog(p, fmt, ap);
-#else
 	fprintf(stderr, "%s ", LOG__(p));
 	vfprintf(stderr, fmt, ap);
 	fprintf(stderr, "\n");
-#endif
 }
 
 static void _syslog(int p, const char *fmt, ...)
 {
 	va_list ap;
 	va_start(ap , fmt);
-#ifdef K_USING_SYSLOG
-	vsyslog(p, fmt, ap);
-#else
 	fprintf(stderr, "%s ", LOG__(p));
 	vfprintf(stderr, fmt, ap);
 	fprintf(stderr, "\n");
-#endif
 	va_end(ap);
 }
 
