@@ -142,7 +142,7 @@ void knh_write_uline(Ctx *ctx, knh_OutputStream_t *w, knh_uri_t uri, long line)
 
 static knh_bool_t isCalledMethod(Ctx *ctx, knh_sfp_t *sfp)
 {
-	knh_Method_t *mtd = sfp[0].mtdNC;
+	knh_Method_t *mtd = sfp[0].callmtd;
 	if(knh_isObject(ctx, mtd) && IS_Method(mtd)) {
 		DBG_P("shift=%d, pc=%d", sfp[-2].shift, sfp[-1].pc);
 		return 1;
@@ -152,7 +152,7 @@ static knh_bool_t isCalledMethod(Ctx *ctx, knh_sfp_t *sfp)
 
 static void knh_stack_writeStackTrace(Ctx *ctx, knh_sfp_t *sfp, knh_OutputStream_t *w)
 {
-	knh_Method_t *mtd = sfp[K_MTDIDX].mtdNC;
+	knh_Method_t *mtd = sfp[K_MTDIDX].callmtd;
 	knh_write_sname(ctx, w, DP(mtd)->cid);
 	if(DP(mtd)->mn != MN_LAMBDA) {
 		int i = 0, psize = knh_Method_psize(mtd);
@@ -181,10 +181,10 @@ static knh_Method_t* knh_stack_calleeNULL(Ctx *ctx, knh_sfp_t *sfp, knh_intptr_t
 	knh_intptr_t shift = sfp[K_SHIFTIDX].shift;
 	knh_sfp_t *psfp = sfp - shift;
 	if(ctx->stack < psfp && psfp < sfp) {
-		if(psfp[K_MTDIDX].mtdNC != NULL && isCalledMethod(ctx, psfp + K_MTDIDX)) {
+		if(psfp[K_MTDIDX].callmtd != NULL && isCalledMethod(ctx, psfp + K_MTDIDX)) {
 			knh_opline_t *pc = psfp[K_SHIFTIDX].pc;
 			*linenum = pc->line;
-			return psfp[K_MTDIDX].mtdNC;
+			return psfp[K_MTDIDX].callmtd;
 		}
 	}
 	return NULL;
@@ -196,10 +196,10 @@ static knh_sfp_t *knh_Exception_addStackTrace(Ctx *ctx, knh_Exception_t *e, knh_
 	knh_intptr_t shift = sfp[K_SHIFTIDX].shift;
 	knh_sfp_t *psfp = sfp - shift;
 	if(ctx->stack < psfp && psfp < sfp) {
-		if(psfp[K_MTDIDX].mtdNC != NULL && isCalledMethod(ctx, psfp + K_MTDIDX)) {
+		if(psfp[K_MTDIDX].callmtd != NULL && isCalledMethod(ctx, psfp + K_MTDIDX)) {
 			knh_cwb_t cwbbuf, *cwb = knh_cwb_open(ctx, &cwbbuf);
 			knh_opline_t *pc = psfp[K_SHIFTIDX].pc;
-			knh_Method_t *mtd = psfp[K_MTDIDX].mtdNC;
+			knh_Method_t *mtd = psfp[K_MTDIDX].callmtd;
 			int linenum = pc->line;
 			const char *file = knh_Method_file(ctx, mtd);
 			knh_write_cline(ctx, cwb->w, file, linenum);
@@ -228,7 +228,7 @@ void knh_throw(Ctx *ctx, knh_sfp_t *sfp, long start)
 		knh_sfp_t *sp = (sfp == NULL) ? ctx->esp : sfp + start;
 		while(ctx->stack <= sp) {
 			DBG_P("[%d] cid=%s ivalue=%lld", (sp - ctx->stack), CLASS__(knh_Object_cid(sp[0].o)), sp[0].ivalue);
-			if(sp[0].mtdNC != NULL && isCalledMethod(ctx, sp)) {
+			if(sp[0].callmtd != NULL && isCalledMethod(ctx, sp)) {
 				sp = knh_Exception_addStackTrace(ctx, ctx->e, sp+1);
 			}
 			if(IS_ExceptionHandler(sp[0].hdr) && DP(sp[0].hdr)->return_address != NULL) {
@@ -273,21 +273,20 @@ static void knh_vsyslog(Ctx *ctx, int p, const char *fmt, va_list ap)
 
 #define K_EVENT_FORMAT "<%s:%s> "
 
-void knh_trace(Ctx *ctx, int p, const char *ns, const char *event, knh_sfp_t *sfp, const char *fmt, ...)
+void knh_logevent(Ctx *ctx, int p, const char *ns, const char *event, knh_sfp_t *sfp, const char *fmt, ...)
 {
 	if(p <= LOG_WARNING || knh_isSystemVerbose()) {
 		va_list ap;
 		va_start(ap , fmt);
-		((knh_Context_t*)ctx)->seq += 1;
 		if(fmt[0] == '*') {
 			char newfmt[512];
-			knh_snprintf(newfmt, sizeof(newfmt), "%s+" K_INT_FMT " " K_EVENT_FORMAT "%s", ctx->trace, ctx->seq, ns, event, fmt+1);
+			knh_snprintf(newfmt, sizeof(newfmt), K_EVENT_FORMAT "%s", ns, event, fmt+1);
 			ctx->share->ebiSPI->vsyslog(p, newfmt, ap);
 		}
 		else {
 			DBG_ASSERT(ctx->bufa != NULL);
 			knh_cwb_t cwbbuf, *cwb = knh_cwb_open(ctx, &cwbbuf);
-			knh_printf(ctx, cwb->w, "%s+%i " K_EVENT_FORMAT, ctx->trace, ctx->seq, ns, event);
+			knh_printf(ctx, cwb->w, K_EVENT_FORMAT, ns, event);
 			if(ctx->gma != NULL && SP(ctx->gma)->line != 0) {
 				knh_write_uline(ctx, cwb->w, SP(ctx->gma)->uri, SP(ctx->gma)->line);
 			}
@@ -347,17 +346,12 @@ void THROW_NoSuchMethod(Ctx *ctx, knh_sfp_t *sfp, knh_class_t cid, knh_methodn_t
 	KNH_SYSLOG(ctx, LOG_CRIT, "NoSuchMethod!!", "%C.%M", cid, mn);
 }
 
-void THROW_ClassCast(Ctx *ctx, knh_sfp_t *sfp, const char *msg, knh_class_t cid)
-{
-	KNH_SYSLOG(ctx, LOG_CRIT, "ClassCast!!", "%s for %C", msg, cid);
-}
-
 void THROW_ParamTypeError(Ctx *ctx, knh_sfp_t *sfp, size_t n, knh_methodn_t mn, knh_class_t reqt, knh_class_t cid)
 {
 	KNH_SYSLOG(ctx, LOG_CRIT, "Type!!", "%d of %M NOT %T", n, mn, cid);
 }
 
-/* ------------------------------------------------------------------------ */
+/* ======================================================================== */
 /* [perror] */
 
 void knh_foundKonohaStyle(Ctx *ctx, size_t score)
@@ -398,12 +392,12 @@ void knh_vperror(Ctx *ctx, knh_uri_t uri, int line, int pe, const char *fmt, va_
 //	else if(pe < KERR_TINFO) {
 //		DP(ctx->gma)->statBadManner += 1;
 //	}
-	if(knh_Context_isInteractive(ctx) && knh_Context_isCompiling(ctx)) {
+	if(knh_Context_isInteractive(ctx)) {
 		goto L_PRINT;
 	}
-//	if(pe > KERR_EWARN && !knh_isSystemVerbose()) {
-//		return;
-//	}
+	if(pe > KERR_EWARN && !knh_Context_isCompiling(ctx)) {
+		return;
+	}
 	L_PRINT:;
 	if(line > 0) {
 		knh_OutputStream_t *w = KNH_STDERR;
