@@ -187,7 +187,7 @@ const knh_ExportsAPI_t *knh_getExportsAPI(void)
 	static knh_ExportsAPI_t exports = {
 		knh_fastmalloc, knh_fastfree, /* memory.c */
 		knh_setsfp, knh_Iterator_close,
-		knh_trace, knh_stack_perror, dbg_p, todo_p,
+		knh_logevent, knh_stack_perror, dbg_p, todo_p,
 		knh_cwb_clearAPI, knh_cwb_tocharAPI,
 		new_StringAPI, knh_String_text,
 		new_RawPtr, knh_RawPtr_init,
@@ -466,11 +466,6 @@ static void knh_addConverterDSPI(Ctx *ctx, const char *scheme, const knh_ConvDSP
 	knh_addDSPI(ctx, scheme, (knh_DSPI_t*)d);
 }
 
-static void knh_addMapDSPI(Ctx *ctx, const char *scheme, const knh_MapDSPI_t *d, int isOVERRIDE)
-{
-	knh_addDSPI(ctx, scheme, (knh_DSPI_t*)d);
-}
-
 /* ------------------------------------------------------------------------ */
 
 const knh_PackageLoaderAPI_t* knh_getPackageAPI(void)
@@ -482,7 +477,7 @@ const knh_PackageLoaderAPI_t* knh_getPackageAPI(void)
 		knh_setShellSPI,
 		knh_setEbiSPI,
 		knh_addPathDSPI, knh_addStreamDSPI, knh_addQueryDSPI,
-		knh_addConverterDSPI, knh_addMapDSPI
+		knh_addConverterDSPI,
 	};
 	return &exports;
 }
