@@ -52,9 +52,8 @@ extern "C" {
 //	m->map = m->dspi->init(ctx, init, path, NULL);
 //	return m;
 //}
-static knh_Iterator_t *map_toIterator(Ctx *ctx, knh_Map_t *m, enum mapitr_type type, knh_Fitrnext fnexts[]);
 
-#define K_USING_HASHMAP 1
+//#define K_USING_HASHMAP 1
 #ifdef K_USING_HASHMAP
 
 /* ------------------------------------------------------------------------ */
@@ -376,79 +375,12 @@ static size_t hmap_size(Ctx *ctx, knh_map_t* m)
 	return hmap->size;
 }
 
-static ITRNEXT hmap_next(Ctx *ctx, knh_sfp_t *sfp, long rtnidx)
-{
-	knh_Iterator_t *it = sfp[0].it;
-	knh_Map_t *m = (knh_Map_t*) DP(it)->source;
-	knh_hmap_t *hmap = m->hmap;
-	knh_hentry_t **hentry = knh_map_hentry(hmap);
-	size_t pos;
-	for(pos = DP(it)->pos; pos < hmap->hmax; pos++) {
-		knh_hentry_t *e = hentry[pos];
-		while(e != NULL) {
-			knh_Tuple_t *t = new_Tuple(ctx, knh_Object_cid(e->value), 2);
-			KNH_SETv(ctx, t->first,  e->key);
-			KNH_SETv(ctx, t->second, e->value);
-			DP(it)->pos = pos+1;
-			ITRNEXT_(t);
-			e = e->next;
-		}
-	}
-	DP(it)->pos = pos;
-	ITREND_();
-}
-
-static ITRNEXT hmap_key_next(Ctx *ctx, knh_sfp_t *sfp, long rtnidx)
-{
-	knh_Iterator_t *it = sfp[0].it;
-	knh_Map_t *m = (knh_Map_t*) DP(it)->source;
-	knh_hmap_t *hmap = m->hmap;
-	knh_hentry_t **hentry = knh_map_hentry(hmap);
-	size_t pos;
-	for(pos = DP(it)->pos; pos < hmap->hmax; pos++) {
-		knh_hentry_t *e = hentry[pos];
-		while(e != NULL) {
-			DP(it)->pos = pos+1;
-			ITRNEXT_(e->key);
-			e = e->next;
-		}
-	}
-	DP(it)->pos = pos;
-	ITREND_();
-}
-
-static ITRNEXT hmap_value_next(Ctx *ctx, knh_sfp_t *sfp, long rtnidx)
-{
-	knh_Iterator_t *it = sfp[0].it;
-	knh_Map_t *m = (knh_Map_t*) DP(it)->source;
-	knh_hmap_t *hmap = m->hmap;
-	knh_hentry_t **hentry = knh_map_hentry(hmap);
-	size_t pos;
-	for(pos = DP(it)->pos; pos < hmap->hmax; pos++) {
-		knh_hentry_t *e = hentry[pos];
-		while(e != NULL) {
-			DP(it)->pos = pos+1;
-			ITRNEXT_(e->value);
-			e = e->next;
-		}
-	}
-
-	DP(it)->pos = pos;
-	ITREND_();
-}
-
 static knh_bool_t hmap_setIterator(Ctx *ctx, knh_map_t* m, knh_Iterator_t *it)
 {
-	it->fnext_1 = DP(it)->fnext = hmap_next;
+	KNH_TODO("hmap_setIterator");
 	return 0;
 }
 
-static knh_Iterator_t *hmap_toIterator(Ctx *ctx, knh_Map_t* m, enum mapitr_type type)
-{
-	knh_Fitrnext fnexts[] = {hmap_next, hmap_key_next, hmap_value_next};
-	return map_toIterator(ctx, m, type, fnexts);
-}
-
 static knh_MapDSPI_t* hmap_config(Ctx *ctx, knh_class_t p1, knh_class_t p2);
 
 static knh_MapDSPI_t MAP_StringObject = {
@@ -456,14 +388,14 @@ static knh_MapDSPI_t MAP_StringObject = {
 	hmap_config,
 	hmap_init, hmap_ftr, hmap_free,
 	hmap_get, hmap_set, hmap_remove, hmap_size,
-	hmap_setIterator,hmap_toIterator,
+	hmap_setIterator,
 };
 
 static knh_MapDSPI_t MAP_StringData = {
 	K_DSPI_MAP, "hash",
 	hmap_config, hmap_init, hmap_ftrdata, hmap_free,
 	hmap_getdata, hmap_setdata, hmap_remove, hmap_size,
-	hmap_setIterator,hmap_toIterator,
+	hmap_setIterator,
 };
 
 //static knh_MapDSPI_t MAP_DataObject = {
@@ -645,66 +577,12 @@ static size_t dmap_size(Ctx *ctx, knh_map_t* m)
 	return dmap->size;
 }
 
-static ITRNEXT dmap_next(Ctx *ctx, knh_sfp_t *sfp, long rtnidx)
-{
-	knh_Iterator_t *it = sfp[0].it;
-	knh_Map_t *m = (knh_Map_t*) DP(it)->source;
-	knh_dmap_t *dmap = knh_map_dmap(m->dmap);
-	knh_dentry_t *dentry = knh_map_dentry(m->dmap);
-	size_t i;
-	for(i = DP(it)->pos; i < dmap->size; i++) {
-		knh_Tuple_t *t = new_Tuple(ctx, knh_Object_cid(dentry[i].value), 2);
-		KNH_SETv(ctx, t->first,  dentry[i].key);
-		KNH_SETv(ctx, t->second, dentry[i].value);
-		DP(it)->pos = i+1;
-		ITRNEXT_(t);
-	}
-	DP(it)->pos = i;
-	ITREND_();
-}
-
 static knh_bool_t dmap_setIterator(Ctx *ctx, knh_map_t* m, knh_Iterator_t *it)
 {
-	it->fnext_1 = DP(it)->fnext = dmap_next;
+	KNH_TODO("dmap_setIterator");
 	return 0;
 }
 
-static ITRNEXT dmap_key_next(Ctx *ctx, knh_sfp_t *sfp, long rtnidx)
-{
-	knh_Iterator_t *it = sfp[0].it;
-	knh_Map_t *m = (knh_Map_t*) DP(it)->source;
-	knh_dmap_t *dmap = knh_map_dmap(m->dmap);
-	knh_dentry_t *dentry = knh_map_dentry(m->dmap);
-	size_t i;
-	for(i = DP(it)->pos; i < dmap->size; i++) {
-		DP(it)->pos = i+1;
-		ITRNEXT_(dentry[i].key);
-	}
-	DP(it)->pos = i;
-	ITREND_();
-}
-
-static ITRNEXT dmap_value_next(Ctx *ctx, knh_sfp_t *sfp, long rtnidx)
-{
-	knh_Iterator_t *it = sfp[0].it;
-	knh_Map_t *m = (knh_Map_t*) DP(it)->source;
-	knh_dmap_t *dmap = knh_map_dmap(m->dmap);
-	knh_dentry_t *dentry = knh_map_dentry(m->dmap);
-	size_t i;
-	for(i = DP(it)->pos; i < dmap->size; i++) {
-		DP(it)->pos = i+1;
-		ITRNEXT_(dentry[i].value);
-	}
-	DP(it)->pos = i;
-	ITREND_();
-}
-
-static knh_Iterator_t *dmap_toIterator(Ctx *ctx, knh_Map_t* m, enum mapitr_type type)
-{
-	knh_Fitrnext fnexts[] = {dmap_next, dmap_key_next, dmap_value_next};
-	return map_toIterator(ctx, m, type, fnexts);
-}
-
 /* ------------------------------------------------------------------------ */
 /* int */
 //
@@ -1027,7 +905,7 @@ static knh_MapDSPI_t DMAP_StringObject = {
 	dmap_config,
 	dmap_init, dmap_ftr, dmap_free,
 	dmap_sget, dmap_sset, dmap_sremove, dmap_size,
-	dmap_setIterator, dmap_toIterator,
+	dmap_setIterator,
 };
 
 static knh_MapDSPI_t DMAP_StringInt = {
@@ -1035,7 +913,7 @@ static knh_MapDSPI_t DMAP_StringInt = {
 	dmap_config,
 	dmap_init, dmap_ftrdata, dmap_free,
 	dmap_sgetint, dmap_ssetint, dmap_sremovedata, dmap_size,
-	dmap_setIterator, dmap_toIterator,
+	dmap_setIterator,
 };
 
 static knh_MapDSPI_t DMAP_StringFloat = {
@@ -1043,7 +921,7 @@ static knh_MapDSPI_t DMAP_StringFloat = {
 	dmap_config,
 	dmap_init, dmap_ftrdata, dmap_free,
 	dmap_sgetfloat, dmap_ssetfloat, dmap_sremovedata, dmap_size,
-	dmap_setIterator, dmap_toIterator,
+	dmap_setIterator,
 };
 
 static knh_MapDSPI_t* dmap_config(Ctx *ctx, knh_class_t p1, knh_class_t p2)
@@ -1449,74 +1327,6 @@ void knh_loadDefaultMapDSPI(Ctx *ctx)
 	knh_addDSPI(ctx, "casedict", (knh_DSPI_t*)&CASEMAP_StringObject);
 }
 
-/* ------------------------------------------------------------------------ */
-
-knh_MapDSPI_t *knh_getMapDSPI(Ctx *ctx, knh_bytes_t path)
-{
-	if(path.len == 0) {
-		return &DMAP_StringObject;
-	}
-	else {
-		knh_MapDSPI_t *p = (knh_MapDSPI_t*) knh_getDSPINULL(ctx, K_DSPI_MAP, path);
-		if(p == NULL) {
-			//SYSLOG_UnknownPathType(ctx, path);
-			p = &DMAP_StringObject;
-		}
-		return p;
-	}
-}
-
-knh_MapDSPI_t *knh_getMapDSPIfromCID(Ctx *ctx, knh_class_t p1, knh_class_t p2)
-{
-#ifdef K_USING_HASHMAP
-	if(IS_Tstr(p1)) {
-		if(IS_Tunbox(p2)) {
-			return &MAP_StringData;
-		}
-		return &MAP_StringObject;
-	}
-#endif
-	if(IS_Tstr(p1)) {
-		if(IS_Tint(p2) || p2 == TYPE_Boolean) {
-			return &DMAP_StringInt;
-		}
-		if(IS_Tfloat(p1)) {
-			return &DMAP_StringFloat;
-		}
-		return &DMAP_StringObject;
-	}
-	return &DMAP_StringObject;
-}
-/* ------------------------------------------------------------------------ */
-
-static knh_Iterator_t *map_toIterator(Ctx *ctx, knh_Map_t *m, enum mapitr_type type, knh_Fitrnext fnexts[])
-{
-	knh_Iterator_t *itr;
-	knh_class_t cid = knh_Object_cid(m);
-	knh_class_t ecid; /* Iterator's entry class id */
-	knh_Fitrnext fnext;
-	switch (type) {
-	case MAPITR_KEY:
-		ecid  = knh_class_p1(cid);
-		fnext = fnexts[1];
-		break;
-	case MAPITR_VALUE:
-		ecid = knh_class_p2(cid);
-		fnext = fnexts[2];
-		break;
-	case MAPITR_KEYVALUE:
-	default:
-		// TODO 
-		ecid = CLASS_Tuple;
-		fnext = fnexts[0];
-		break;
-	}
-	itr = new_Iterator(ctx, ecid, UPCAST(m), NULL);
-	itr->fnext_1 = DP(itr)->fnext = fnext;
-	return itr;
-}
-
-/* ------------------------------------------------------------------------ */
 #ifdef __cplusplus
 }
 #endif
