@@ -195,7 +195,7 @@ void knh_write_mn(Ctx *ctx, knh_OutputStream_t *w, knh_methodn_t mn)
 
 static METHOD knh_Fmethod_abstract(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	knh_Method_t *mtd = sfp[K_MTDIDX].mtdNC;
+	knh_Method_t *mtd = sfp[K_MTDIDX].callmtd;
 	knh_type_t rtype = knh_type_tocid(ctx, knh_ParamArray_rtype(DP(mtd)->mp), knh_Object_cid(sfp[0].o));
 	KNH_SYSLOG(ctx, LOG_NOTICE, "CALLED_AbstractMethod", "%O", mtd);
 	if(rtype != TYPE_void) {
@@ -300,41 +300,41 @@ static size_t knh_typeof(Ctx *ctx, knh_type_t t)
 
 static METHOD knh_Fmethod_getter(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	int delta = DP(sfp[K_MTDIDX].mtdNC)->delta;
+	int delta = DP(sfp[K_MTDIDX].callmtd)->delta;
 	RETURN_((sfp[0].ox)->fields[delta]);
 }
 
 static METHOD knh_Fmethod_igetter(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	int delta = DP(sfp[K_MTDIDX].mtdNC)->delta;
+	int delta = DP(sfp[K_MTDIDX].callmtd)->delta;
 	knh_int_t *data = (knh_int_t*)(&(sfp[0].ox->fields[delta]));
 	RETURNi_(data[0]);
 }
 
 static METHOD knh_Fmethod_fgetter(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	int delta = DP(sfp[K_MTDIDX].mtdNC)->delta;
+	int delta = DP(sfp[K_MTDIDX].callmtd)->delta;
 	knh_float_t *data = (knh_float_t*)(&(sfp[0].ox->fields[delta]));
 	RETURNf_(data[0]);
 }
 
 static METHOD knh_Fmethod_bgetter(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	int delta = DP(sfp[K_MTDIDX].mtdNC)->delta;
+	int delta = DP(sfp[K_MTDIDX].callmtd)->delta;
 	knh_bool_t *data = (knh_bool_t*)(&(sfp[0].ox->fields[delta]));
 	RETURNb_(data[0]);
 }
 
 static METHOD knh_Fmethod_setter(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	int delta = DP(sfp[K_MTDIDX].mtdNC)->delta;
-	KNH_SETv(ctx, (sfp[0].ox)->fields[delta], sfp[1].o);
+	int delta = DP(sfp[K_MTDIDX].callmtd)->delta;
+	klr_mov(ctx, (sfp[0].ox)->fields[delta], sfp[1].o);
 	RETURN_(sfp[1].o);
 }
 
 static METHOD knh_Fmethod_bsetter(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	int delta = DP(sfp[K_MTDIDX].mtdNC)->delta;
+	int delta = DP(sfp[K_MTDIDX].callmtd)->delta;
 	knh_bool_t *data = (knh_bool_t*)(&((sfp[0].ox)->fields[delta]));
 	data[0] = sfp[1].bvalue;
 	RETURNb_(sfp[1].bvalue);
@@ -342,7 +342,7 @@ static METHOD knh_Fmethod_bsetter(Ctx *ctx, knh_sfp_t *sfp, long rix)
 
 static METHOD knh_Fmethod_isetter(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	int delta = DP(sfp[K_MTDIDX].mtdNC)->delta;
+	int delta = DP(sfp[K_MTDIDX].callmtd)->delta;
 	knh_int_t *data = (knh_int_t*)(&(sfp[0].ox)->fields[delta]);
 	data[0] = sfp[1].ivalue;
 	RETURNi_(sfp[1].ivalue);
@@ -350,7 +350,7 @@ static METHOD knh_Fmethod_isetter(Ctx *ctx, knh_sfp_t *sfp, long rix)
 
 static METHOD knh_Fmethod_fsetter(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	int delta = DP(sfp[K_MTDIDX].mtdNC)->delta;
+	int delta = DP(sfp[K_MTDIDX].callmtd)->delta;
 	knh_float_t *data = (knh_float_t*)(&(sfp[0].ox)->fields[delta]);
 	data[0] = sfp[1].fvalue;
 	RETURNf_(sfp[1].fvalue);
@@ -422,7 +422,7 @@ knh_Method_t* knh_Array_findMethodNULL(Ctx *ctx, knh_Array_t *a, knh_methodn_t m
 
 static METHOD knh_Fmethod_NoSuchMethod(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	knh_Method_t *mtd = sfp[K_MTDIDX].mtdNC;
+	knh_Method_t *mtd = sfp[K_MTDIDX].callmtd;
 	KNH_ASSERT(IS_Method(mtd));
 	knh_class_t cid = knh_Method_isStatic(mtd) ? DP(mtd)->cid : knh_Object_cid(sfp[0].o);
 	THROW_NoSuchMethod(ctx, sfp, cid, DP(mtd)->mn);
