@@ -35,6 +35,7 @@
 #define USE_cwb_tobytes   1
 #define USE_cwb_size      1
 
+
 /* ************************************************************************ */
 // added by nakata
 #define USE_cwb_write 1
@@ -51,7 +52,7 @@ extern "C" {
 #endif
 
 
-/* ------------------------------------------------------------------------ */
+/* ======================================================================== */
 /* [ctxkey] */
 
 #ifdef K_USING_THREAD
@@ -72,7 +73,7 @@ void knh_opcode_check(void);
 void konoha_init(void)
 {
 	static int isInit = 0;
-	if(isInit == 0) {
+	if(isInit==0) {
 		knh_opcode_check();
 #if defined(K_USING_THREAD) && !defined(K_CC_TLS)
 		knh_thread_key_create((knh_thread_key_t*)&ctxkey);
@@ -85,7 +86,7 @@ void konoha_init(void)
 /* ------------------------------------------------------------------------ */
 /* [Context] */
 
-Ctx* knh_beginContext(Ctx *ctx, Ctx **bottom)
+KNHAPI(Ctx*) knh_beginContext(Ctx *ctx, Ctx **bottom)
 {
 	((knh_Context_t*)ctx)->cstack_bottom = (void**)bottom;
 #ifdef K_USING_THREAD
@@ -102,7 +103,7 @@ Ctx* knh_beginContext(Ctx *ctx, Ctx **bottom)
 
 /* ------------------------------------------------------------------------ */
 
-void knh_endContext(Ctx *ctx)
+KNHAPI(void) knh_endContext(Ctx *ctx)
 {
 #ifdef K_USING_THREAD
 #if !defined(K_CC_TLS)
@@ -157,10 +158,7 @@ static void knh_setVerboseMode(Ctx *ctx, int mode, const char *optstr)
 		KNH_ASSERT(sizeof(knh_intptr_t) == sizeof(void*));
 		KNH_SYSLOG(ctx, LOG_DEBUG, "Memory", "*sizeof(knh_int_t)=%d, sizeof(knh_float_t)=%d", sizeof(knh_int_t), sizeof(knh_float_t));
 		KNH_ASSERT(sizeof(knh_int_t) <= sizeof(knh_float_t));
-		KNH_SYSLOG(ctx, LOG_DEBUG, "Memory", "*sizeof(knh_sfp_t)=%d, sizeof(knh_rbp_t)=%d, sizeof(Ctx)=%d", sizeof(knh_sfp_t), sizeof(knh_rbp_t), sizeof(knh_Context_t));
-#ifdef K_USING_RBP
-		KNH_ASSERT(sizeof(knh_rbp_t) * 2 == sizeof(knh_sfp_t));
-#endif
+		KNH_SYSLOG(ctx, LOG_DEBUG, "Memory", "*sizeof(knh_sfp_t)=%d, sizeof(Ctx)=%d", sizeof(knh_sfp_t), sizeof(knh_Context_t));
 		KNH_SYSLOG(ctx, LOG_DEBUG, "Memory", "*sizeof(Object)=%d FASTMALLOC=%d", sizeof(knh_Object_t), K_FASTMALLOC_SIZE);
 		KNH_SYSLOG(ctx, LOG_DEBUG, "Memory", "*sizeof(knh_opline_t)=%d FASTMALLOC=%d", sizeof(knh_opline_t), K_FASTMALLOC_SIZE);
 	}
@@ -201,7 +199,7 @@ static void knh_setOptimizationMode(Ctx *ctx, int mode, const char *optstr)
 	}
 }
 
-/* ----------------------------------------------------------------------- */
+/* ************************************************************************ */
 
 static knh_bool_t toTestMode = 0;
 
@@ -215,13 +213,13 @@ static void knh_setTestMode(Ctx *ctx, int mode, const char *optstr)
 	toTestMode = 1;
 }
 
-/* ----------------------------------------------------------------------- */
+/* ************************************************************************ */
 
-//static void knh_setSyncURL(Ctx *ctx, int mode, const char *optstr)
-//{
-//	DBG_P("SYNC URL: %s", optstr);
-//	KNH_TODO("sync");
-//}
+static void knh_setSyncURL(Ctx *ctx, int mode, const char *optstr)
+{
+	DBG_P("SYNC URL: %s", optstr);
+	KNH_TODO("sync");
+}
 
 void knh_loadPackageList(Ctx *ctx, const char *pkglist)
 {
@@ -292,7 +290,7 @@ static knh_optdata_t optdata[] = {
 	{"-v", OPT_NUMBER, knh_setVerboseMode},
 	{"-O", OPT_NUMBER, knh_setOptimizationMode},
 	{"-P", OPT_STRING, knh_setStartUpPackage},
-//	{"-u", OPT_STRING, knh_setSyncURL},
+	{"-u", OPT_STRING, knh_setSyncURL},
 	{"-t", OPT_EMPTY,  knh_setTestMode},
 	{NULL, OPT_EMPTY, NULL}, // END
 };
@@ -333,7 +331,7 @@ knh_bytes_t knh_bytes_nsname(knh_bytes_t t)
 	return t;
 }
 
-KNHAPI(int) konoha_parseopt(konoha_t konoha, int argc, const char **argv)
+int konoha_parseopt(konoha_t konoha, int argc, const char **argv)
 {
 	KONOHA_CHECK(konoha, 1);
 	Ctx *ctx = konoha.ctx;
@@ -395,25 +393,16 @@ KNHAPI(int) konoha_parseopt(konoha_t konoha, int argc, const char **argv)
 		if(argc > 0) {
 			knh_String_t *s = new_T(argv[0]);
 			knh_DictMap_set(ctx, DP(ctx->sys)->props, new_T("script.name"), s);
-#ifdef K_USING_SYSLOG
-			openlog(knh_sfile(S_tochar(s)), LOG_PID, LOG_LOCAL7);
-#endif
 			s = new_S(ctx, knh_bytes_nsname(S_tobytes(s)));
 			KNH_SETv(ctx, DP(ctx->share->mainns)->nsname, s);
 		}
 	}
-	{
-		char *trace = knh_getenv("TRACE");
-		if(trace != NULL) {
-			KNH_SYSLOG(ctx, LOG_NOTICE, "TracedBy", "%s", trace);
-		}
-	}
 	return n;
 }
 
 /* ------------------------------------------------------------------------ */
 
-KNHAPI(int) konoha_runMain(konoha_t konoha, int argc, const char **argv)
+int konoha_runMain(konoha_t konoha, int argc, const char **argv)
 {
 	KONOHA_CHECK(konoha, -1);
 	Ctx *ctx = KONOHA_BEGIN(konoha.ctx);
@@ -424,7 +413,7 @@ KNHAPI(int) konoha_runMain(konoha_t konoha, int argc, const char **argv)
 		BEGIN_LOCAL(ctx, lsfp, 5);
 		lsfp[1].ivalue = 0;
 		lsfp[thisidx+K_PCIDX].pc = NULL;
-		klr_setmtdNC(ctx,lsfp[thisidx+K_MTDIDX], mtd);
+		klr_setcallmtd(ctx,lsfp[thisidx+K_MTDIDX], mtd);
 		KNH_SETv(ctx, lsfp[thisidx].o, ctx->script);
 		KNH_SETv(ctx, lsfp[thisidx+1].o, knh_getPropertyNULL(ctx, STEXT("script.argv")));
 		klr_setesp(ctx, lsfp + thisidx+2);
@@ -455,9 +444,6 @@ static void knh_showWelcome(Ctx *ctx, knh_OutputStream_t *w)
 #ifdef K_USING_RCGC
 	knh_write_text(ctx, w, " rcgc");
 #endif
-#ifdef K_USING_SYSLOG
-	knh_write_text(ctx, w, " syslog");
-#endif
 #ifdef K_USING_THREAD
 	knh_write_text(ctx, w, " thread");
 #endif
@@ -718,122 +704,16 @@ typedef struct _kt_status_t {
 	size_t unitsize;
 	kt_unit_t *uhead;
 	kt_unit_t *current;
-	knh_uint_t seek_cur; // added for rewind
 	size_t     lineno;
 	size_t     sumOfPassed;
 	size_t     sumOfFailed;
-	void (*envConv)(char*, size_t);
 } kt_status_t ;
 
-
-// DOS CRLF
-// UNIX(OSX, Linux) LF
-// Mac Classic CR
-
-#define CR 0x0D
-#define LF 0x0A
-
-enum kt_env {
-	KT_ENV_UNKNOWN,
-	KT_ENV_WINDOWS,
-	KT_ENV_UNIX,
-	KT_ENV_MACOS9,
-};
-
-#if defined(KONOHA_ON_WINDOWS) || defined(KONOHA_ON_MINGW) || defined(KONOHA_ON_CYGWIN)
-static void kt_conv_LFtoCRLF(char *buf, size_t len)
-{
-	// code is UNIX, run on WIN
-	// suppose it ends with LF.
-	DBG_ASSERT(buf[len - 1] == LF);
-	DBG_ASSERT(len < KTEST_LINE_MAX - 1);
-	buf[len - 1] = CR;
-	buf[len] = LF;
-	buf[len + 1] = '\0';
-}
-#endif
-
-#if defined(KONOHA_ON_MACOSX) || defined(KONOHA_ON_LINUX)
-static void kt_conv_CRLFtoLF(char *buf, size_t len)
-{
-	// code is WIN, run on UNIX
-	// suppose it ends with CRLF
-	DBG_ASSERT(buf[len - 1] == LF && buf[len - 2] == CR);
-	buf[len - 2] = LF;
-	buf[len - 1] = '\0';
-}
-#endif
-
-static void kt_conv_nop(char *buf, size_t len)
-{
-	// do nothing.
-}
-
-static void detectEnv (kt_status_t *kt, char *line) {
-	size_t linelen = knh_strlen(line);
-	int i = linelen;
-	char ch = 0;
-	knh_bool_t done_flag = 0;
-	enum kt_env code_env = KT_ENV_UNKNOWN;
-	// choose envConv function;
-	void (*conv_table[4])(char*, size_t) = {
-		kt_conv_nop,
-#if defined(KONOHA_ON_MACOSX) || defined(KONOHA_ON_LINUX)
-		kt_conv_CRLFtoLF,
-		kt_conv_nop, 
-		kt_conv_nop 
-#elif defined(KONOHA_ON_WINDOWS) || defined(KONOHA_ON_MINGW) || defined(KONOHA_ON_CYGWIN)
-		kt_conv_nop,
-		kt_conv_LFtoCRLF,
-		kt_conv_nop
-#else
-	/* we should find out MACOS9 */
-		kt_conv_nop,
-		kt_conv_nop,
-		kt_conv_nop
-#endif
-	};
-	
-	if (linelen <= 2) return;
-	while (done_flag == 0 && i > 0) {
-		ch = line[i--];
-		if (ch == LF || ch == CR) {
-			done_flag = 1;
-		}
-	}
-	if(done_flag == 0) return ;
-	if (ch == LF) {
-		// this is DOS or Unix
-		if (i > 1 && line[i] == CR) {
-			// this is WINDOWS
-			code_env = KT_ENV_WINDOWS;
-		} else {
-			// this is Unix
-			code_env = KT_ENV_UNIX;
-		}
-	} else if (ch == CR) {
-		// this is MacOS9
-		code_env = KT_ENV_MACOS9;
-	}
-	//else {
-	//never come here
-	//  }
-	
-	kt->envConv = conv_table[code_env];
-}
-
 static char *kt_fgets(Ctx *ctx, kt_status_t *kt, char *line, int max)
 {
 	char *ret;
-	size_t len = 0;
 	if ((ret = fgets(line, max - 1, kt->in)) != NULL) {
-	    len = knh_strlen(line);
-		DBG_ASSERT(len > 0);
-		line[len] = '\0';
-		kt->seek_cur += (knh_uint_t)len;
-		if (kt->envConv != NULL) {
-		  kt->envConv(line, len);
-		}
+		line[strlen(line)] = '\0';
 	}
 	return ret;
 }
@@ -897,14 +777,6 @@ static void* test_init(Ctx *ctx, const char *msg, const char *filename)
 		kt->lineno = 0;
 		kt->sumOfPassed = 0;
 		kt->sumOfFailed = 0;
-
-		// check env difference
-		char line[KTEST_LINE_MAX] = {0};
-		kt->envConv = NULL;
-		kt_fgets(ctx, kt, line, KTEST_LINE_MAX);
-		fseek(kt->in, 0, SEEK_SET);
-		kt->seek_cur = 0;
-		detectEnv(kt, line);
 		return kt;
 	}
 }
@@ -963,8 +835,7 @@ static knh_bool_t test_readstmt(Ctx *ctx, void *status, knh_cwb_t *cwb, const kn
 	if (ks != NULL && ks->next != NULL) {
 		ks = ks->next;
 		ku->current = ks;
-		// TODO : should also consider for windows 
-		if (ks->testBody.len == 1 && ks->testBody.text[0] == LF) {
+		if(ks->testBody.len == 1 && ks->testBody.text[0] == '\n') {
 			/* assured as passed */
 			kt->sumOfPassed++;
 			ks->isPassed = 1;
@@ -1042,13 +913,10 @@ static knh_bool_t test_readstmt(Ctx *ctx, void *status, knh_cwb_t *cwb, const kn
 		if (IS_T(line_ptr, '#')) {
 			if (isUnitStarted) {
 				if (ku->stmtsize != 0) {
-					// next unit test. we need to rewind fp;
-					// TODO: alternate fseek for windows implementation -> DONE
-					// see what we have till '10/10/31
-					size_t len = knh_strlen(line_ptr);
-					kt->seek_cur -= (len + 1);
-					//					fseek(kt->in, -(len + 1), SEEK_CUR);
-					fseek(kt->in, (long)kt->seek_cur, SEEK_SET);
+				// next unit test. we need to rewind fp;
+					// TODO: alternate fseek for windows implementation
+					long len = (long)knh_strlen(line);
+					fseek(kt->in, -(len + 1), SEEK_CUR);
 					kt->lineno -= 1;
 					break;
 				} else {
@@ -1057,6 +925,7 @@ static knh_bool_t test_readstmt(Ctx *ctx, void *status, knh_cwb_t *cwb, const kn
 			}
 			line_ptr += 4;
 			size_t title_len = knh_strlen(line_ptr);
+
 			kt_truncate_line(line_ptr);
 			if (kt->unitsize == 0) {
 				kt->uhead = new_kt_unit(ctx, line_ptr);
@@ -1074,10 +943,11 @@ static knh_bool_t test_readstmt(Ctx *ctx, void *status, knh_cwb_t *cwb, const kn
 			}
 			continue;
 		}
-		
+
 		if (IS_T(line_ptr, '>')) {
 			line_ptr += 4;
 			if (ku == NULL) continue; // invalid test stmt
+//			kt_truncate_line(line_ptr);
 			if (ku->stmtsize == 0) {
 				ku->shead = new_kt_stmt(ctx, line_ptr);
 				ks = ku->shead;
@@ -1128,10 +998,10 @@ static knh_bool_t test_readstmt(Ctx *ctx, void *status, knh_cwb_t *cwb, const kn
 		}
 		// handle result
 		if (isResultReady) {
-		  // should also consider CR+LF..
-		  if ((line_ptr[0] != LF) && line_ptr[0] != '\0') {
+			if (line_ptr[0] != '\n' && line_ptr[0] != '\0') {
 				add_kt_stmt_result(ctx, ks, line_ptr);
 			}
+
 		}
 	}
 	if (isUnitStarted && ku->current != NULL) {
@@ -1168,6 +1038,7 @@ static void test_display(Ctx *ctx, void *status, const char* result, const knh_S
 	if (ku == NULL) return;
 	ks = ku->current;
 	size_t len = knh_strlen(result);
+
 	// we cannot know if there is a result or?
 	if (ks->testResult.len == 0) {
 		//ignoring result;
@@ -1221,7 +1092,7 @@ static void test_cleanup(Ctx *ctx, void *status)
 		size_t i, j;
 		/* traverse test result, and sum up */
 		size_t unit_passed = 0, isAllPassed = 1, line = 0;
-		size_t ignore_units = 0; /* for TODOs, and Empties */
+		size_t total_stmts = 0, ignore_units = 0; /* for TODOs, and Empties */
 		for (i = 1; i <= kt->unitsize; i++) {
 			if (ku->stmtsize ==0) {
 				clean_ku = ku;
@@ -1234,6 +1105,7 @@ static void test_cleanup(Ctx *ctx, void *status)
 				KNH_FREE(ctx, clean_ku, sizeof(kt_unit_t));
 				continue;
 			}// ignore
+			total_stmts += ku->stmtsize;
 			for (j = 1; j <= ku->stmtsize; j++) {
 				if (ks->isPassed == 0 /*failed*/) {
 					line = j;
@@ -1276,14 +1148,14 @@ static void test_cleanup(Ctx *ctx, void *status)
 }
 
 static const knh_ShellSPI_t testSPI = {
-	"konoha builtin test mode",
-	test_init,
-	test_readstmt,
-	test_display,
-	test_cleanup,
+		"konoha builtin test mode",
+		test_init,
+		test_readstmt,
+		test_display,
+		test_cleanup,
 };
 
-KNHAPI(void) konoha_runTest(konoha_t konoha, int argc, const char **argv)
+void konoha_runTest(konoha_t konoha, int argc, const char **argv)
 {
 	KONOHA_CHECK_(konoha);
 	Ctx *ctx = KONOHA_BEGIN(konoha.ctx);
