@@ -73,19 +73,19 @@ void knh_addTranslatorFunc(Ctx *ctx, knh_flag_t flag, knh_type_t stype, knh_type
 
 static TCAST knh_Ftranslator_null(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	//KNH_TODO("null translator");
+	KNH_TODO("null translator");
 //	DBG_(
-//	knh_Translator_t *trl = sfp[0].trlNC;
+//	knh_Translator_t *trl = sfp[0].casttrl;
 //	DBG_P("trl: %s ==> %s", CLASS__(SP(trl)->scid), CLASS__(SP(trl)->tcid));
 //	);
-	THROW_ClassCast(ctx, sfp, "Null translator", knh_Object_cid(sfp[0].o));
+//	KNH_THROW__T(ctx, "ClassCast!!");
 }
 
 ///* ------------------------------------------------------------------------ */
 //
 //static TCAST knh_Ftranslator_method(Ctx *ctx, knh_sfp_t *sfp, long rix)
 //{
-//	knh_Method_t *mtd = DP(sfp[0].trlNC)->mtd;
+//	knh_Method_t *mtd = DP(sfp[0].casttrl)->mtd;
 //	DBG_ASSERT(IS_Method(mtd));
 //	KNH_SETv(ctx, sfp[1+K_CALLDELTA].o, sfp[0].o);
 //	KNH_SCALL(ctx, sfp, 1, mtd, /*argc*/, 0);
@@ -116,7 +116,7 @@ KNHAPI(knh_Translator_t*) new_Translator(Ctx *ctx, knh_flag_t flag, knh_class_t
 //
 //static TCAST knh_Ftranslator_mapmap(Ctx *ctx, knh_sfp_t *sfp, long rix)
 //{
-//	knh_Translator_t *trl = sfp[K_TRLIDX].trlNC;
+//	knh_Translator_t *trl = sfp[K_TRLIDX].casttrl;
 //	DBG_ASSERT(IS_Translator(trl));
 //	knh_Translator_t *m1 = DP(trl)->m1, *m2 = DP(trl)->m2;
 //	DBG_ASSERT(IS_Translator(m1));
@@ -181,7 +181,6 @@ static knh_Translator_t *knh_setTranslatorCache(Ctx *ctx, knh_class_t scid, knh_
 
 static TCAST knh_Ftranslator_asis(Ctx *ctx, knh_sfp_t *sfp, long rix)
 {
-	sfp[rix].data = knh_Object_data(sfp[rix].o);
 	KNH_SWAPMOV(ctx, sfp, rix, 0);
 }
 
@@ -231,24 +230,6 @@ knh_Translator_t *knh_findTranslatorNULL(Ctx *ctx, knh_class_t scid, knh_class_t
 					goto L_SETCACHE;
 				}
 			}
-			if(knh_class_isGenerics(ctx, sbcid) &&
-					knh_class_isGenerics(ctx, tcid)) {
-				knh_ParamArray_t *spa = ClassTBL(sbcid).cparam;
-				knh_ParamArray_t *tpa = ClassTBL(tcid).cparam;
-				if (knh_ParamArray_equalsType(spa, tpa)) {
-					knh_class_t sbbcid =
-						ClassTBL(sbcid).bcid;
-					knh_class_t tbcid = ClassTBL(tcid).bcid;
-					knh_Array_t *ga =
-						ClassTBL(sbbcid).tmaps;
-					for(i = 0; i < (ga)->size; i++) {
-						trl = (ga)->trans[i];
-						if(SP(trl)->tcid == tbcid) {
-							goto L_SETCACHE;
-						}
-					}
-				}
-			}
 			if(sbcid == CLASS_Object) break;
 			for(i = 0; i < (a)->size; i++) {
 				size_t j;
